#ifndef __ADI_ID00_STOCK_MODE_H__
#define __ADI_ID00_STOCK_MODE_H__

#include <stdbool.h>
#include <stddef.h>
#include <stdint.h>
#include "apollo_cpu_device_profile_types.h"

adi_apollo_top_t id00_stock_mode_0 = { 
		.profile_cfg = { 
		.profile_version = { 
		.major = 9, 
		.minor = 1, 
		.patch = 0 }
		, 
		.config_version = 0, 
		.is_8t8r = false }
	, 
		.clk_cfg = { 
		.single_dual_clk_sel = false, 
		.clk_path_sel = true, 
		.ref_clk_freq_kHz = 0, 
		.clocking_mode = ADI_APOLLO_CLOCKING_MODE_SDR_DIV_8, 
		.adc_divby2 = { false, false  }, 
		.dac_divby2 = { true, true  }, 
		.adc_inclk_invert0 = { false, false  }, 
		.adc_inclk_invert1 = { false, false  }, 
		.dev_clk_freq_kHz = 20000000, 
		.arm_clock_sel = ADI_APOLLO_ARM_CLOCK_SEL_A, 
		.arm_clk_div = 5, 
		.serdes_clk_div = 16 }
	, 
		.clk_pll = { 
		.loop_bandwidth = 0, 
		.phase_margin = 0, 
		.div_range = 0, 
		.div2 = 0, 
		.power = 0, 
		.ref_clk_div = 1, 
		.i_bleed_en = 0, 
		.feedback_int = 0, 
		.feedback_frac = 0 }
	, 
		.mcs_cfg = { 
		.center_sysref = { 
		.ref_to_int_period_ratio = 1, 
		.sysref_present = false, 
		.rx_term_en = false, 
		.cm_above_900mv = false }
		, 
		.aside_sysref = { 
		.ref_to_int_period_ratio = 1, 
		.sysref_present = false, 
		.rx_term_en = false, 
		.cm_above_900mv = false }
		, 
		.bside_sysref = { 
		.ref_to_int_period_ratio = 1, 
		.sysref_present = false, 
		.rx_term_en = false, 
		.cm_above_900mv = false }
		, 
		.use_gapped_sysref = false, 
		.leave_sysref_rx_on = false, 
		.num_sysref_avg_mcs_fw = 31, 
		.sysref_lock_window_mcs_fw = 0, 
		.internal_sysref_prd_digclk_cycles_center = 256, 
		.internal_sysref_prd_digclk_cycles_side_a = 256, 
		.internal_sysref_prd_digclk_cycles_side_b = 256, 
		.adf4382_cfg = { 
		.center_adf4382_clock_align_config = 0, 
		.aside_adf4382_clock_align_config = 0, 
		.bside_adf4382_clock_align_config = 0, 
		.correction_mode = ADI_APOLLO_ADF4382_CORR_INT, 
		.clock_align_delay_adjust_gpio = { 16, 0  }, 
		.clock_align_delay_strobe_gpio = { 15, 0  }, 
		.max_coarse_code = { 0, 0  }, 
		.max_fine_code = { 0, 0  }, 
		.track_polarity_select = { false, false  }, 
		.phase_adj = { 1, 0  }, 
		.track_win = { 0, 0  } }
		, 
		.mcs_trigger_cfg = { 
		.trigger_pin_to_rx_datapath_a_mapping = 0, 
		.trigger_pin_to_rx_datapath_b_mapping = 0, 
		.trigger_pin_to_tx_datapath_a_mapping = 0, 
		.trigger_pin_to_tx_datapath_b_mapping = 0 }
		 }
	, 
		.gpio_cfg = { 
		.gpio_quick_config = 0, 
		.gpio_mode_en = 0, 
		.gpio_mode_dir = 0, 
		.gpio_from_master = 0, 
		.gpio_from_set = 0, 
		.gpio_source_control = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.gpio_stage_sel_lsb = 0, 
		.gpio_stage_sel_msb = 0 }
	, 
		.tx_path = { { 
		.tx_cduc = { { 
		.nco = { { 
		.drc_en = true, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_COMPLEX, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_1, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 214748365, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_DIRECT_REGMAP, 
		.nco_auto_inc_dec = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.debug_cdrc_clkoff_n = true }, { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_0p7, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 0, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_TRIG_AUTO, 
		.nco_auto_inc_dec = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.debug_cdrc_clkoff_n = false }  }, 
		.drc_ratio = ADI_APOLLO_CDUC_INTERP_4 }, { 
		.nco = { { 
		.drc_en = true, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_COMPLEX, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_1, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 214748365, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_DIRECT_REGMAP, 
		.nco_auto_inc_dec = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.debug_cdrc_clkoff_n = true }, { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_0p7, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 0, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_TRIG_AUTO, 
		.nco_auto_inc_dec = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.debug_cdrc_clkoff_n = false }  }, 
		.drc_ratio = ADI_APOLLO_CDUC_INTERP_4 }  }, 
		.tx_fduc = { { 
		.nco = { { 
		.drc_en = true, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_COMPLEX, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_1, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 5629499534213, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_DIRECT_REGMAP, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = ADI_APOLLO_FNCO_TRIG_HOP_FREQ, 
		.debug_fdrc_clkoff_n = true }, { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_0p7, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 0, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_TRIG_AUTO, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = (adi_apollo_fnco_trig_hop_sel_e) 0, 
		.debug_fdrc_clkoff_n = false }  }, 
		.drc_ratio = ADI_APOLLO_FDUC_RATIO_2, 
		.sub_dp_gain_en = false, 
		.subdp_gain = 0 }, { 
		.nco = { { 
		.drc_en = true, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_COMPLEX, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_1, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 5629499534213, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_DIRECT_REGMAP, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = ADI_APOLLO_FNCO_TRIG_HOP_FREQ, 
		.debug_fdrc_clkoff_n = true }, { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_0p7, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 0, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_TRIG_AUTO, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = (adi_apollo_fnco_trig_hop_sel_e) 0, 
		.debug_fdrc_clkoff_n = false }  }, 
		.drc_ratio = ADI_APOLLO_FDUC_RATIO_2, 
		.sub_dp_gain_en = false, 
		.subdp_gain = 0 }, { 
		.nco = { { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_COMPLEX, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_1, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 5629499534213, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_DIRECT_REGMAP, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = ADI_APOLLO_FNCO_TRIG_HOP_FREQ, 
		.debug_fdrc_clkoff_n = true }, { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_0p7, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 0, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_TRIG_AUTO, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = (adi_apollo_fnco_trig_hop_sel_e) 0, 
		.debug_fdrc_clkoff_n = false }  }, 
		.drc_ratio = ADI_APOLLO_FDUC_RATIO_2, 
		.sub_dp_gain_en = false, 
		.subdp_gain = 0 }, { 
		.nco = { { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_COMPLEX, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_1, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 5629499534213, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_DIRECT_REGMAP, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = ADI_APOLLO_FNCO_TRIG_HOP_FREQ, 
		.debug_fdrc_clkoff_n = true }, { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_0p7, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 0, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_TRIG_AUTO, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = (adi_apollo_fnco_trig_hop_sel_e) 0, 
		.debug_fdrc_clkoff_n = false }  }, 
		.drc_ratio = ADI_APOLLO_FDUC_RATIO_2, 
		.sub_dp_gain_en = false, 
		.subdp_gain = 0 }  }, 
		.tx_pfilt = { { 
		.enable = false, 
		.coeffs = { 
				{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
				{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
				{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
				{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
			 }, 
		.i_mode = ADI_APOLLO_PFILT_MODE_DISABLED, 
		.q_mode = ADI_APOLLO_PFILT_MODE_DISABLED, 
		.real_data = ADI_APOLLO_PFILT_COMPLEX_DATA, 
		.dq_mode = ADI_APOLLO_PFILT_DUAL_MODE, 
		.add_sub_sel = ADI_APOLLO_PFILT_SUB_FOR_MOD_SW, 
		.mode_switch = ADI_APOLLO_PFILT_DISABLE_3DB_AVG_MOD_SW, 
		.pfir_ix_gain_db = { ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB  }, 
		.pfir_iy_gain_db = { ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB  }, 
		.pfir_qx_gain_db = { ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB  }, 
		.pfir_qy_gain_db = { ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB  }, 
		.pfir_ix_scalar_gain_db = { 0, 0, 0, 0  }, 
		.pfir_iy_scalar_gain_db = { 0, 0, 0, 0  }, 
		.pfir_qx_scalar_gain_db = { 0, 0, 0, 0  }, 
		.pfir_qy_scalar_gain_db = { 0, 0, 0, 0  }, 
		.hc_prog_delay = { 0, 0, 0, 0  } }  }, 
		.tx_cfir = { { 
		.coeffs_i = { 
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 },
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 }
			 }, 
		.coeffs_q = { 
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 },
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 }
			 }, 
		.cfir_gain_dB = { 
				{ ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB  },
				{ ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB  }
			 }, 
		.scalar_i = { 
				{ 0, 0, 0, 0  },
				{ 0, 0, 0, 0  }
			 }, 
		.scalar_q = { 
				{ 0, 0, 0, 0  },
				{ 0, 0, 0, 0  }
			 }, 
		.enable = false, 
		.sparse_mode = false, 
		.cfir_mode = ADI_APOLLO_CFIR_SINGLE_BAND }, { 
		.coeffs_i = { 
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 },
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 }
			 }, 
		.coeffs_q = { 
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 },
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 }
			 }, 
		.cfir_gain_dB = { 
				{ ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB  },
				{ ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB  }
			 }, 
		.scalar_i = { 
				{ 0, 0, 0, 0  },
				{ 0, 0, 0, 0  }
			 }, 
		.scalar_q = { 
				{ 0, 0, 0, 0  },
				{ 0, 0, 0, 0  }
			 }, 
		.enable = false, 
		.sparse_mode = false, 
		.cfir_mode = ADI_APOLLO_CFIR_SINGLE_BAND }  }, 
		.tx_fsrc = { { 
		.fsrc_rate_int = 0, 
		.fsrc_rate_frac_a = 0, 
		.fsrc_rate_frac_b = 0, 
		.fsrc_delay = 0, 
		.gain_reduction = 0, 
		.ptr_syncrstval = 0, 
		.ptr_overwrite = false, 
		.data_mult_dither_en = false, 
		.dither_en = false, 
		.split_4t4r = false, 
		.mode_1x = false, 
		.enable = false }, { 
		.fsrc_rate_int = 0, 
		.fsrc_rate_frac_a = 0, 
		.fsrc_rate_frac_b = 0, 
		.fsrc_delay = 0, 
		.gain_reduction = 0, 
		.ptr_syncrstval = 0, 
		.ptr_overwrite = false, 
		.data_mult_dither_en = false, 
		.dither_en = false, 
		.split_4t4r = false, 
		.mode_1x = false, 
		.enable = false }  }, 
		.tx_mux_summer_xbar = { 
		.cduc_dac_enables = { 0, 2, 1, 3  }, 
		.fduc_cduc_summer = { 1, 2, 0, 0  }, 
		.mux1_sel = { ADI_APOLLO_4T4R_MODSW0_OUT0_FROM_I0_OUT1_FROM_I1, ADI_APOLLO_4T4R_MODSW0_OUT0_FROM_I0_OUT1_FROM_I1  }, 
		.mux0_sel = { (adi_apollo_tx_mux0_sel_e) 0, (adi_apollo_tx_mux0_sel_e) 1, (adi_apollo_tx_mux0_sel_e) 0, (adi_apollo_tx_mux0_sel_e) 1  }, 
		.low_samp_en = false }
		, 
		.tx_dyn_recfg = { 
		.prefsrc_lcm = 0, 
		.postfsrc_lcm = 0, 
		.trig_recfg_mode = false, 
		.cnco_rst_en = false, 
		.fnco_rst_en = false, 
		.resync_en = false, 
		.ts_rst_en = false, 
		.tzero_coher_en = false }
		, 
		.tx_pa_prot = { { 
		.pa_clkdiv_en = false, 
		.paprot_pwr_cfg = { 
		.pa_clk_en = false, 
		.short_pac_en = false, 
		.long_pac_en = false, 
		.pwr_threshold_long = 0, 
		.pwr_threshold_short = 0, 
		.avg_long_win = 0, 
		.avg_short_win = 0 }
			, 
		.paprot_sm_cfg = { 
		.enable_paprotsm = false, 
		.rampdwn_to_papin_en = false, 
		.srl_err_en = false, 
		.avg_pwr_err_en = false, 
		.auto_dyn_reconf_en = false, 
		.jesd_err_en = false, 
		.jesd_err_auto_config_en = false, 
		.data_ready_auto_config_en = false, 
		.zero_flush_clock_stable_rise_en = false, 
		.zero_flush_dyn_reconf_ramp_up_en = false, 
		.zero_flush_txen_fall_en = false, 
		.zero_flush_txen_rise_en = false, 
		.zero_flush_start_en = false, 
		.drive_sm_by_dig_en = false, 
		.hold_sample_en = false, 
		.skip_ramp_up = false, 
		.skip_ramp_down = false, 
		.ramp_up_timer_en = false, 
		.ramp_dwn_timer_en = false, 
		.zero_flush_timer = 0, 
		.ramp_down_timer_val = 0, 
		.ramp_up_timer_val = 0, 
		.dp_zero_flush_sel_0 = ADI_APOLLO_PAPROT_ZF_SEL_F0_P0, 
		.dp_zero_flush_sel_1 = ADI_APOLLO_PAPROT_ZF_SEL_F0_P0, 
		.data_ready_sel_ramp = ADI_APOLLO_PAPROT_JESD_DF_SEL_L0, 
		.jesd_err_sel_ramp = ADI_APOLLO_PAPROT_JESD_DF_SEL_L0 }
			, 
		.paprot_ramp_cfg = { 
		.gain_clk_en = false, 
		.zero_detect_en = false, 
		.force_ramps_dyn_recfig_en = false, 
		.force_ramp_up_en = false, 
		.force_ramp_dwn_en = false, 
		.enable_gain = false, 
		.enable_ramp = false, 
		.trig_ramp_together = false, 
		.gain_inc_step = 0, 
		.gain_dec_step = 0, 
		.gain_max_val = 0 }
			, 
		.paprot_sr_cfg = { 
		.sr_clk_en = false, 
		.sr_err_self_clr_en = false, 
		.sr_calculation_en = false, 
		.slew_rate_err_irq_en = false, 
		.sr_path_sel = 0, 
		.sr_threshold = 0 }
			 }, { 
		.pa_clkdiv_en = false, 
		.paprot_pwr_cfg = { 
		.pa_clk_en = false, 
		.short_pac_en = false, 
		.long_pac_en = false, 
		.pwr_threshold_long = 0, 
		.pwr_threshold_short = 0, 
		.avg_long_win = 0, 
		.avg_short_win = 0 }
			, 
		.paprot_sm_cfg = { 
		.enable_paprotsm = false, 
		.rampdwn_to_papin_en = false, 
		.srl_err_en = false, 
		.avg_pwr_err_en = false, 
		.auto_dyn_reconf_en = false, 
		.jesd_err_en = false, 
		.jesd_err_auto_config_en = false, 
		.data_ready_auto_config_en = false, 
		.zero_flush_clock_stable_rise_en = false, 
		.zero_flush_dyn_reconf_ramp_up_en = false, 
		.zero_flush_txen_fall_en = false, 
		.zero_flush_txen_rise_en = false, 
		.zero_flush_start_en = false, 
		.drive_sm_by_dig_en = false, 
		.hold_sample_en = false, 
		.skip_ramp_up = false, 
		.skip_ramp_down = false, 
		.ramp_up_timer_en = false, 
		.ramp_dwn_timer_en = false, 
		.zero_flush_timer = 0, 
		.ramp_down_timer_val = 0, 
		.ramp_up_timer_val = 0, 
		.dp_zero_flush_sel_0 = ADI_APOLLO_PAPROT_ZF_SEL_F0_P0, 
		.dp_zero_flush_sel_1 = ADI_APOLLO_PAPROT_ZF_SEL_F0_P0, 
		.data_ready_sel_ramp = ADI_APOLLO_PAPROT_JESD_DF_SEL_L0, 
		.jesd_err_sel_ramp = ADI_APOLLO_PAPROT_JESD_DF_SEL_L0 }
			, 
		.paprot_ramp_cfg = { 
		.gain_clk_en = false, 
		.zero_detect_en = false, 
		.force_ramps_dyn_recfig_en = false, 
		.force_ramp_up_en = false, 
		.force_ramp_dwn_en = false, 
		.enable_gain = false, 
		.enable_ramp = false, 
		.trig_ramp_together = false, 
		.gain_inc_step = 0, 
		.gain_dec_step = 0, 
		.gain_max_val = 0 }
			, 
		.paprot_sr_cfg = { 
		.sr_clk_en = false, 
		.sr_err_self_clr_en = false, 
		.sr_calculation_en = false, 
		.slew_rate_err_irq_en = false, 
		.sr_path_sel = 0, 
		.sr_threshold = 0 }
			 }, { 
		.pa_clkdiv_en = false, 
		.paprot_pwr_cfg = { 
		.pa_clk_en = false, 
		.short_pac_en = false, 
		.long_pac_en = false, 
		.pwr_threshold_long = 0, 
		.pwr_threshold_short = 0, 
		.avg_long_win = 0, 
		.avg_short_win = 0 }
			, 
		.paprot_sm_cfg = { 
		.enable_paprotsm = false, 
		.rampdwn_to_papin_en = false, 
		.srl_err_en = false, 
		.avg_pwr_err_en = false, 
		.auto_dyn_reconf_en = false, 
		.jesd_err_en = false, 
		.jesd_err_auto_config_en = false, 
		.data_ready_auto_config_en = false, 
		.zero_flush_clock_stable_rise_en = false, 
		.zero_flush_dyn_reconf_ramp_up_en = false, 
		.zero_flush_txen_fall_en = false, 
		.zero_flush_txen_rise_en = false, 
		.zero_flush_start_en = false, 
		.drive_sm_by_dig_en = false, 
		.hold_sample_en = false, 
		.skip_ramp_up = false, 
		.skip_ramp_down = false, 
		.ramp_up_timer_en = false, 
		.ramp_dwn_timer_en = false, 
		.zero_flush_timer = 0, 
		.ramp_down_timer_val = 0, 
		.ramp_up_timer_val = 0, 
		.dp_zero_flush_sel_0 = ADI_APOLLO_PAPROT_ZF_SEL_F0_P0, 
		.dp_zero_flush_sel_1 = ADI_APOLLO_PAPROT_ZF_SEL_F0_P0, 
		.data_ready_sel_ramp = ADI_APOLLO_PAPROT_JESD_DF_SEL_L0, 
		.jesd_err_sel_ramp = ADI_APOLLO_PAPROT_JESD_DF_SEL_L0 }
			, 
		.paprot_ramp_cfg = { 
		.gain_clk_en = false, 
		.zero_detect_en = false, 
		.force_ramps_dyn_recfig_en = false, 
		.force_ramp_up_en = false, 
		.force_ramp_dwn_en = false, 
		.enable_gain = false, 
		.enable_ramp = false, 
		.trig_ramp_together = false, 
		.gain_inc_step = 0, 
		.gain_dec_step = 0, 
		.gain_max_val = 0 }
			, 
		.paprot_sr_cfg = { 
		.sr_clk_en = false, 
		.sr_err_self_clr_en = false, 
		.sr_calculation_en = false, 
		.slew_rate_err_irq_en = false, 
		.sr_path_sel = 0, 
		.sr_threshold = 0 }
			 }, { 
		.pa_clkdiv_en = false, 
		.paprot_pwr_cfg = { 
		.pa_clk_en = false, 
		.short_pac_en = false, 
		.long_pac_en = false, 
		.pwr_threshold_long = 0, 
		.pwr_threshold_short = 0, 
		.avg_long_win = 0, 
		.avg_short_win = 0 }
			, 
		.paprot_sm_cfg = { 
		.enable_paprotsm = false, 
		.rampdwn_to_papin_en = false, 
		.srl_err_en = false, 
		.avg_pwr_err_en = false, 
		.auto_dyn_reconf_en = false, 
		.jesd_err_en = false, 
		.jesd_err_auto_config_en = false, 
		.data_ready_auto_config_en = false, 
		.zero_flush_clock_stable_rise_en = false, 
		.zero_flush_dyn_reconf_ramp_up_en = false, 
		.zero_flush_txen_fall_en = false, 
		.zero_flush_txen_rise_en = false, 
		.zero_flush_start_en = false, 
		.drive_sm_by_dig_en = false, 
		.hold_sample_en = false, 
		.skip_ramp_up = false, 
		.skip_ramp_down = false, 
		.ramp_up_timer_en = false, 
		.ramp_dwn_timer_en = false, 
		.zero_flush_timer = 0, 
		.ramp_down_timer_val = 0, 
		.ramp_up_timer_val = 0, 
		.dp_zero_flush_sel_0 = ADI_APOLLO_PAPROT_ZF_SEL_F0_P0, 
		.dp_zero_flush_sel_1 = ADI_APOLLO_PAPROT_ZF_SEL_F0_P0, 
		.data_ready_sel_ramp = ADI_APOLLO_PAPROT_JESD_DF_SEL_L0, 
		.jesd_err_sel_ramp = ADI_APOLLO_PAPROT_JESD_DF_SEL_L0 }
			, 
		.paprot_ramp_cfg = { 
		.gain_clk_en = false, 
		.zero_detect_en = false, 
		.force_ramps_dyn_recfig_en = false, 
		.force_ramp_up_en = false, 
		.force_ramp_dwn_en = false, 
		.enable_gain = false, 
		.enable_ramp = false, 
		.trig_ramp_together = false, 
		.gain_inc_step = 0, 
		.gain_dec_step = 0, 
		.gain_max_val = 0 }
			, 
		.paprot_sr_cfg = { 
		.sr_clk_en = false, 
		.sr_err_self_clr_en = false, 
		.sr_calculation_en = false, 
		.slew_rate_err_irq_en = false, 
		.sr_path_sel = 0, 
		.sr_threshold = 0 }
			 }  }, 
		.inv_sinc_en = { true, true, false, false  } }, { 
		.tx_cduc = { { 
		.nco = { { 
		.drc_en = true, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_COMPLEX, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_1, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 214748365, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_DIRECT_REGMAP, 
		.nco_auto_inc_dec = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.debug_cdrc_clkoff_n = true }, { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_0p7, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 0, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_TRIG_AUTO, 
		.nco_auto_inc_dec = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.debug_cdrc_clkoff_n = false }  }, 
		.drc_ratio = ADI_APOLLO_CDUC_INTERP_4 }, { 
		.nco = { { 
		.drc_en = true, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_COMPLEX, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_1, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 214748365, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_DIRECT_REGMAP, 
		.nco_auto_inc_dec = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.debug_cdrc_clkoff_n = true }, { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_0p7, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 0, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_TRIG_AUTO, 
		.nco_auto_inc_dec = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.debug_cdrc_clkoff_n = false }  }, 
		.drc_ratio = ADI_APOLLO_CDUC_INTERP_4 }  }, 
		.tx_fduc = { { 
		.nco = { { 
		.drc_en = true, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_COMPLEX, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_1, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 5629499534213, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_DIRECT_REGMAP, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = ADI_APOLLO_FNCO_TRIG_HOP_FREQ, 
		.debug_fdrc_clkoff_n = true }, { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_0p7, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 0, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_TRIG_AUTO, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = (adi_apollo_fnco_trig_hop_sel_e) 0, 
		.debug_fdrc_clkoff_n = false }  }, 
		.drc_ratio = ADI_APOLLO_FDUC_RATIO_2, 
		.sub_dp_gain_en = false, 
		.subdp_gain = 0 }, { 
		.nco = { { 
		.drc_en = true, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_COMPLEX, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_1, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 5629499534213, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_DIRECT_REGMAP, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = ADI_APOLLO_FNCO_TRIG_HOP_FREQ, 
		.debug_fdrc_clkoff_n = true }, { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_0p7, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 0, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_TRIG_AUTO, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = (adi_apollo_fnco_trig_hop_sel_e) 0, 
		.debug_fdrc_clkoff_n = false }  }, 
		.drc_ratio = ADI_APOLLO_FDUC_RATIO_2, 
		.sub_dp_gain_en = false, 
		.subdp_gain = 0 }, { 
		.nco = { { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_COMPLEX, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_1, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 5629499534213, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_DIRECT_REGMAP, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = ADI_APOLLO_FNCO_TRIG_HOP_FREQ, 
		.debug_fdrc_clkoff_n = true }, { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_0p7, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 0, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_TRIG_AUTO, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = (adi_apollo_fnco_trig_hop_sel_e) 0, 
		.debug_fdrc_clkoff_n = false }  }, 
		.drc_ratio = ADI_APOLLO_FDUC_RATIO_2, 
		.sub_dp_gain_en = false, 
		.subdp_gain = 0 }, { 
		.nco = { { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_COMPLEX, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_1, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 5629499534213, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_DIRECT_REGMAP, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = ADI_APOLLO_FNCO_TRIG_HOP_FREQ, 
		.debug_fdrc_clkoff_n = true }, { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_0p7, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 0, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_TRIG_AUTO, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = (adi_apollo_fnco_trig_hop_sel_e) 0, 
		.debug_fdrc_clkoff_n = false }  }, 
		.drc_ratio = ADI_APOLLO_FDUC_RATIO_2, 
		.sub_dp_gain_en = false, 
		.subdp_gain = 0 }  }, 
		.tx_pfilt = { { 
		.enable = false, 
		.coeffs = { 
				{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
				{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
				{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
				{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
			 }, 
		.i_mode = ADI_APOLLO_PFILT_MODE_DISABLED, 
		.q_mode = ADI_APOLLO_PFILT_MODE_DISABLED, 
		.real_data = ADI_APOLLO_PFILT_COMPLEX_DATA, 
		.dq_mode = ADI_APOLLO_PFILT_DUAL_MODE, 
		.add_sub_sel = ADI_APOLLO_PFILT_SUB_FOR_MOD_SW, 
		.mode_switch = ADI_APOLLO_PFILT_DISABLE_3DB_AVG_MOD_SW, 
		.pfir_ix_gain_db = { ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB  }, 
		.pfir_iy_gain_db = { ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB  }, 
		.pfir_qx_gain_db = { ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB  }, 
		.pfir_qy_gain_db = { ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB  }, 
		.pfir_ix_scalar_gain_db = { 0, 0, 0, 0  }, 
		.pfir_iy_scalar_gain_db = { 0, 0, 0, 0  }, 
		.pfir_qx_scalar_gain_db = { 0, 0, 0, 0  }, 
		.pfir_qy_scalar_gain_db = { 0, 0, 0, 0  }, 
		.hc_prog_delay = { 0, 0, 0, 0  } }  }, 
		.tx_cfir = { { 
		.coeffs_i = { 
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 },
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 }
			 }, 
		.coeffs_q = { 
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 },
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 }
			 }, 
		.cfir_gain_dB = { 
				{ ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB  },
				{ ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB  }
			 }, 
		.scalar_i = { 
				{ 0, 0, 0, 0  },
				{ 0, 0, 0, 0  }
			 }, 
		.scalar_q = { 
				{ 0, 0, 0, 0  },
				{ 0, 0, 0, 0  }
			 }, 
		.enable = false, 
		.sparse_mode = false, 
		.cfir_mode = ADI_APOLLO_CFIR_SINGLE_BAND }, { 
		.coeffs_i = { 
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 },
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 }
			 }, 
		.coeffs_q = { 
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 },
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 }
			 }, 
		.cfir_gain_dB = { 
				{ ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB  },
				{ ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB  }
			 }, 
		.scalar_i = { 
				{ 0, 0, 0, 0  },
				{ 0, 0, 0, 0  }
			 }, 
		.scalar_q = { 
				{ 0, 0, 0, 0  },
				{ 0, 0, 0, 0  }
			 }, 
		.enable = false, 
		.sparse_mode = false, 
		.cfir_mode = ADI_APOLLO_CFIR_SINGLE_BAND }  }, 
		.tx_fsrc = { { 
		.fsrc_rate_int = 0, 
		.fsrc_rate_frac_a = 0, 
		.fsrc_rate_frac_b = 0, 
		.fsrc_delay = 0, 
		.gain_reduction = 0, 
		.ptr_syncrstval = 0, 
		.ptr_overwrite = false, 
		.data_mult_dither_en = false, 
		.dither_en = false, 
		.split_4t4r = false, 
		.mode_1x = false, 
		.enable = false }, { 
		.fsrc_rate_int = 0, 
		.fsrc_rate_frac_a = 0, 
		.fsrc_rate_frac_b = 0, 
		.fsrc_delay = 0, 
		.gain_reduction = 0, 
		.ptr_syncrstval = 0, 
		.ptr_overwrite = false, 
		.data_mult_dither_en = false, 
		.dither_en = false, 
		.split_4t4r = false, 
		.mode_1x = false, 
		.enable = false }  }, 
		.tx_mux_summer_xbar = { 
		.cduc_dac_enables = { 0, 2, 1, 3  }, 
		.fduc_cduc_summer = { 1, 2, 0, 0  }, 
		.mux1_sel = { ADI_APOLLO_4T4R_MODSW0_OUT0_FROM_I0_OUT1_FROM_I1, ADI_APOLLO_4T4R_MODSW0_OUT0_FROM_I0_OUT1_FROM_I1  }, 
		.mux0_sel = { (adi_apollo_tx_mux0_sel_e) 0, (adi_apollo_tx_mux0_sel_e) 1, (adi_apollo_tx_mux0_sel_e) 0, (adi_apollo_tx_mux0_sel_e) 1  }, 
		.low_samp_en = false }
		, 
		.tx_dyn_recfg = { 
		.prefsrc_lcm = 0, 
		.postfsrc_lcm = 0, 
		.trig_recfg_mode = false, 
		.cnco_rst_en = false, 
		.fnco_rst_en = false, 
		.resync_en = false, 
		.ts_rst_en = false, 
		.tzero_coher_en = false }
		, 
		.tx_pa_prot = { { 
		.pa_clkdiv_en = false, 
		.paprot_pwr_cfg = { 
		.pa_clk_en = false, 
		.short_pac_en = false, 
		.long_pac_en = false, 
		.pwr_threshold_long = 0, 
		.pwr_threshold_short = 0, 
		.avg_long_win = 0, 
		.avg_short_win = 0 }
			, 
		.paprot_sm_cfg = { 
		.enable_paprotsm = false, 
		.rampdwn_to_papin_en = false, 
		.srl_err_en = false, 
		.avg_pwr_err_en = false, 
		.auto_dyn_reconf_en = false, 
		.jesd_err_en = false, 
		.jesd_err_auto_config_en = false, 
		.data_ready_auto_config_en = false, 
		.zero_flush_clock_stable_rise_en = false, 
		.zero_flush_dyn_reconf_ramp_up_en = false, 
		.zero_flush_txen_fall_en = false, 
		.zero_flush_txen_rise_en = false, 
		.zero_flush_start_en = false, 
		.drive_sm_by_dig_en = false, 
		.hold_sample_en = false, 
		.skip_ramp_up = false, 
		.skip_ramp_down = false, 
		.ramp_up_timer_en = false, 
		.ramp_dwn_timer_en = false, 
		.zero_flush_timer = 0, 
		.ramp_down_timer_val = 0, 
		.ramp_up_timer_val = 0, 
		.dp_zero_flush_sel_0 = ADI_APOLLO_PAPROT_ZF_SEL_F0_P0, 
		.dp_zero_flush_sel_1 = ADI_APOLLO_PAPROT_ZF_SEL_F0_P0, 
		.data_ready_sel_ramp = ADI_APOLLO_PAPROT_JESD_DF_SEL_L0, 
		.jesd_err_sel_ramp = ADI_APOLLO_PAPROT_JESD_DF_SEL_L0 }
			, 
		.paprot_ramp_cfg = { 
		.gain_clk_en = false, 
		.zero_detect_en = false, 
		.force_ramps_dyn_recfig_en = false, 
		.force_ramp_up_en = false, 
		.force_ramp_dwn_en = false, 
		.enable_gain = false, 
		.enable_ramp = false, 
		.trig_ramp_together = false, 
		.gain_inc_step = 0, 
		.gain_dec_step = 0, 
		.gain_max_val = 0 }
			, 
		.paprot_sr_cfg = { 
		.sr_clk_en = false, 
		.sr_err_self_clr_en = false, 
		.sr_calculation_en = false, 
		.slew_rate_err_irq_en = false, 
		.sr_path_sel = 0, 
		.sr_threshold = 0 }
			 }, { 
		.pa_clkdiv_en = false, 
		.paprot_pwr_cfg = { 
		.pa_clk_en = false, 
		.short_pac_en = false, 
		.long_pac_en = false, 
		.pwr_threshold_long = 0, 
		.pwr_threshold_short = 0, 
		.avg_long_win = 0, 
		.avg_short_win = 0 }
			, 
		.paprot_sm_cfg = { 
		.enable_paprotsm = false, 
		.rampdwn_to_papin_en = false, 
		.srl_err_en = false, 
		.avg_pwr_err_en = false, 
		.auto_dyn_reconf_en = false, 
		.jesd_err_en = false, 
		.jesd_err_auto_config_en = false, 
		.data_ready_auto_config_en = false, 
		.zero_flush_clock_stable_rise_en = false, 
		.zero_flush_dyn_reconf_ramp_up_en = false, 
		.zero_flush_txen_fall_en = false, 
		.zero_flush_txen_rise_en = false, 
		.zero_flush_start_en = false, 
		.drive_sm_by_dig_en = false, 
		.hold_sample_en = false, 
		.skip_ramp_up = false, 
		.skip_ramp_down = false, 
		.ramp_up_timer_en = false, 
		.ramp_dwn_timer_en = false, 
		.zero_flush_timer = 0, 
		.ramp_down_timer_val = 0, 
		.ramp_up_timer_val = 0, 
		.dp_zero_flush_sel_0 = ADI_APOLLO_PAPROT_ZF_SEL_F0_P0, 
		.dp_zero_flush_sel_1 = ADI_APOLLO_PAPROT_ZF_SEL_F0_P0, 
		.data_ready_sel_ramp = ADI_APOLLO_PAPROT_JESD_DF_SEL_L0, 
		.jesd_err_sel_ramp = ADI_APOLLO_PAPROT_JESD_DF_SEL_L0 }
			, 
		.paprot_ramp_cfg = { 
		.gain_clk_en = false, 
		.zero_detect_en = false, 
		.force_ramps_dyn_recfig_en = false, 
		.force_ramp_up_en = false, 
		.force_ramp_dwn_en = false, 
		.enable_gain = false, 
		.enable_ramp = false, 
		.trig_ramp_together = false, 
		.gain_inc_step = 0, 
		.gain_dec_step = 0, 
		.gain_max_val = 0 }
			, 
		.paprot_sr_cfg = { 
		.sr_clk_en = false, 
		.sr_err_self_clr_en = false, 
		.sr_calculation_en = false, 
		.slew_rate_err_irq_en = false, 
		.sr_path_sel = 0, 
		.sr_threshold = 0 }
			 }, { 
		.pa_clkdiv_en = false, 
		.paprot_pwr_cfg = { 
		.pa_clk_en = false, 
		.short_pac_en = false, 
		.long_pac_en = false, 
		.pwr_threshold_long = 0, 
		.pwr_threshold_short = 0, 
		.avg_long_win = 0, 
		.avg_short_win = 0 }
			, 
		.paprot_sm_cfg = { 
		.enable_paprotsm = false, 
		.rampdwn_to_papin_en = false, 
		.srl_err_en = false, 
		.avg_pwr_err_en = false, 
		.auto_dyn_reconf_en = false, 
		.jesd_err_en = false, 
		.jesd_err_auto_config_en = false, 
		.data_ready_auto_config_en = false, 
		.zero_flush_clock_stable_rise_en = false, 
		.zero_flush_dyn_reconf_ramp_up_en = false, 
		.zero_flush_txen_fall_en = false, 
		.zero_flush_txen_rise_en = false, 
		.zero_flush_start_en = false, 
		.drive_sm_by_dig_en = false, 
		.hold_sample_en = false, 
		.skip_ramp_up = false, 
		.skip_ramp_down = false, 
		.ramp_up_timer_en = false, 
		.ramp_dwn_timer_en = false, 
		.zero_flush_timer = 0, 
		.ramp_down_timer_val = 0, 
		.ramp_up_timer_val = 0, 
		.dp_zero_flush_sel_0 = ADI_APOLLO_PAPROT_ZF_SEL_F0_P0, 
		.dp_zero_flush_sel_1 = ADI_APOLLO_PAPROT_ZF_SEL_F0_P0, 
		.data_ready_sel_ramp = ADI_APOLLO_PAPROT_JESD_DF_SEL_L0, 
		.jesd_err_sel_ramp = ADI_APOLLO_PAPROT_JESD_DF_SEL_L0 }
			, 
		.paprot_ramp_cfg = { 
		.gain_clk_en = false, 
		.zero_detect_en = false, 
		.force_ramps_dyn_recfig_en = false, 
		.force_ramp_up_en = false, 
		.force_ramp_dwn_en = false, 
		.enable_gain = false, 
		.enable_ramp = false, 
		.trig_ramp_together = false, 
		.gain_inc_step = 0, 
		.gain_dec_step = 0, 
		.gain_max_val = 0 }
			, 
		.paprot_sr_cfg = { 
		.sr_clk_en = false, 
		.sr_err_self_clr_en = false, 
		.sr_calculation_en = false, 
		.slew_rate_err_irq_en = false, 
		.sr_path_sel = 0, 
		.sr_threshold = 0 }
			 }, { 
		.pa_clkdiv_en = false, 
		.paprot_pwr_cfg = { 
		.pa_clk_en = false, 
		.short_pac_en = false, 
		.long_pac_en = false, 
		.pwr_threshold_long = 0, 
		.pwr_threshold_short = 0, 
		.avg_long_win = 0, 
		.avg_short_win = 0 }
			, 
		.paprot_sm_cfg = { 
		.enable_paprotsm = false, 
		.rampdwn_to_papin_en = false, 
		.srl_err_en = false, 
		.avg_pwr_err_en = false, 
		.auto_dyn_reconf_en = false, 
		.jesd_err_en = false, 
		.jesd_err_auto_config_en = false, 
		.data_ready_auto_config_en = false, 
		.zero_flush_clock_stable_rise_en = false, 
		.zero_flush_dyn_reconf_ramp_up_en = false, 
		.zero_flush_txen_fall_en = false, 
		.zero_flush_txen_rise_en = false, 
		.zero_flush_start_en = false, 
		.drive_sm_by_dig_en = false, 
		.hold_sample_en = false, 
		.skip_ramp_up = false, 
		.skip_ramp_down = false, 
		.ramp_up_timer_en = false, 
		.ramp_dwn_timer_en = false, 
		.zero_flush_timer = 0, 
		.ramp_down_timer_val = 0, 
		.ramp_up_timer_val = 0, 
		.dp_zero_flush_sel_0 = ADI_APOLLO_PAPROT_ZF_SEL_F0_P0, 
		.dp_zero_flush_sel_1 = ADI_APOLLO_PAPROT_ZF_SEL_F0_P0, 
		.data_ready_sel_ramp = ADI_APOLLO_PAPROT_JESD_DF_SEL_L0, 
		.jesd_err_sel_ramp = ADI_APOLLO_PAPROT_JESD_DF_SEL_L0 }
			, 
		.paprot_ramp_cfg = { 
		.gain_clk_en = false, 
		.zero_detect_en = false, 
		.force_ramps_dyn_recfig_en = false, 
		.force_ramp_up_en = false, 
		.force_ramp_dwn_en = false, 
		.enable_gain = false, 
		.enable_ramp = false, 
		.trig_ramp_together = false, 
		.gain_inc_step = 0, 
		.gain_dec_step = 0, 
		.gain_max_val = 0 }
			, 
		.paprot_sr_cfg = { 
		.sr_clk_en = false, 
		.sr_err_self_clr_en = false, 
		.sr_calculation_en = false, 
		.slew_rate_err_irq_en = false, 
		.sr_path_sel = 0, 
		.sr_threshold = 0 }
			 }  }, 
		.inv_sinc_en = { true, true, false, false  } }  }, 
		.rx_path = { { 
		.rx_cddc = { { 
		.nco = { { 
		.drc_en = true, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_1, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 515396076, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_DIRECT_REGMAP, 
		.nco_auto_inc_dec = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.debug_cdrc_clkoff_n = true }, { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_0p7, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 0, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_TRIG_AUTO, 
		.nco_auto_inc_dec = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.debug_cdrc_clkoff_n = false }  }, 
		.drc_ratio = ADI_APOLLO_CDDC_DCM_4, 
		.fine_bypass = false, 
		.link_num = 0, 
		.hb1_filt_dly_en = false, 
		.hb2_filt_dly_en = false, 
		.tb1_filt_dly_cycles = ADI_APOLLO_TB1_FILT_DLY_DISABLED, 
		.hb1_gain_6db_en = false, 
		.tb1_gain_6db_en = false, 
		.trig_mst_en = false, 
		.trig_mst_period = 0, 
		.trig_mst_offset = 0, 
		.debug_cddc_clkoff_n = 255 }, { 
		.nco = { { 
		.drc_en = true, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_1, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 515396076, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_DIRECT_REGMAP, 
		.nco_auto_inc_dec = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.debug_cdrc_clkoff_n = true }, { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_0p7, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 0, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_TRIG_AUTO, 
		.nco_auto_inc_dec = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.debug_cdrc_clkoff_n = false }  }, 
		.drc_ratio = ADI_APOLLO_CDDC_DCM_4, 
		.fine_bypass = false, 
		.link_num = 0, 
		.hb1_filt_dly_en = false, 
		.hb2_filt_dly_en = false, 
		.tb1_filt_dly_cycles = ADI_APOLLO_TB1_FILT_DLY_DISABLED, 
		.hb1_gain_6db_en = false, 
		.tb1_gain_6db_en = false, 
		.trig_mst_en = false, 
		.trig_mst_period = 0, 
		.trig_mst_offset = 0, 
		.debug_cddc_clkoff_n = 255 }  }, 
		.rx_fddc = { { 
		.nco = { { 
		.drc_en = true, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_COMPLEX, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_1, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 5629499534213, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_DIRECT_REGMAP, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = ADI_APOLLO_FNCO_TRIG_HOP_FREQ, 
		.debug_fdrc_clkoff_n = true }, { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_0p7, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 0, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_TRIG_AUTO, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = (adi_apollo_fnco_trig_hop_sel_e) 0, 
		.debug_fdrc_clkoff_n = false }  }, 
		.drc_ratio = ADI_APOLLO_FDDC_RATIO_2, 
		.link_num = 0, 
		.debug_fddc_clkoff_n = 255, 
		.hb1_filt_dly_en = false, 
		.hb2_filt_dly_en = false, 
		.hb3_filt_dly_en = false, 
		.hb4_filt_dly_en = false, 
		.hb5_filt_dly_en = false, 
		.hb6_filt_dly_en = false, 
		.hb1_gain_6db_en = true }, { 
		.nco = { { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_COMPLEX, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_1, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 5629499534213, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_DIRECT_REGMAP, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = ADI_APOLLO_FNCO_TRIG_HOP_FREQ, 
		.debug_fdrc_clkoff_n = true }, { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_0p7, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 0, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_TRIG_AUTO, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = (adi_apollo_fnco_trig_hop_sel_e) 0, 
		.debug_fdrc_clkoff_n = false }  }, 
		.drc_ratio = ADI_APOLLO_FDDC_RATIO_2, 
		.link_num = 0, 
		.debug_fddc_clkoff_n = 255, 
		.hb1_filt_dly_en = false, 
		.hb2_filt_dly_en = false, 
		.hb3_filt_dly_en = false, 
		.hb4_filt_dly_en = false, 
		.hb5_filt_dly_en = false, 
		.hb6_filt_dly_en = false, 
		.hb1_gain_6db_en = true }, { 
		.nco = { { 
		.drc_en = true, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_COMPLEX, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_1, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 5629499534213, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_DIRECT_REGMAP, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = ADI_APOLLO_FNCO_TRIG_HOP_FREQ, 
		.debug_fdrc_clkoff_n = true }, { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_0p7, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 0, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_TRIG_AUTO, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = (adi_apollo_fnco_trig_hop_sel_e) 0, 
		.debug_fdrc_clkoff_n = false }  }, 
		.drc_ratio = ADI_APOLLO_FDDC_RATIO_2, 
		.link_num = 0, 
		.debug_fddc_clkoff_n = 255, 
		.hb1_filt_dly_en = false, 
		.hb2_filt_dly_en = false, 
		.hb3_filt_dly_en = false, 
		.hb4_filt_dly_en = false, 
		.hb5_filt_dly_en = false, 
		.hb6_filt_dly_en = false, 
		.hb1_gain_6db_en = true }, { 
		.nco = { { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_COMPLEX, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_1, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 5629499534213, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_DIRECT_REGMAP, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = ADI_APOLLO_FNCO_TRIG_HOP_FREQ, 
		.debug_fdrc_clkoff_n = true }, { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_0p7, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 0, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_TRIG_AUTO, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = (adi_apollo_fnco_trig_hop_sel_e) 0, 
		.debug_fdrc_clkoff_n = false }  }, 
		.drc_ratio = ADI_APOLLO_FDDC_RATIO_2, 
		.link_num = 0, 
		.debug_fddc_clkoff_n = 255, 
		.hb1_filt_dly_en = false, 
		.hb2_filt_dly_en = false, 
		.hb3_filt_dly_en = false, 
		.hb4_filt_dly_en = false, 
		.hb5_filt_dly_en = false, 
		.hb6_filt_dly_en = false, 
		.hb1_gain_6db_en = true }  }, 
		.rx_pfilt = { { 
		.enable = false, 
		.coeffs = { 
				{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
				{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
				{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
				{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
			 }, 
		.i_mode = ADI_APOLLO_PFILT_MODE_DISABLED, 
		.q_mode = ADI_APOLLO_PFILT_MODE_DISABLED, 
		.real_data = ADI_APOLLO_PFILT_REAL_DATA, 
		.dq_mode = ADI_APOLLO_PFILT_DUAL_MODE, 
		.add_sub_sel = ADI_APOLLO_PFILT_SUB_FOR_MOD_SW, 
		.mode_switch = ADI_APOLLO_PFILT_DISABLE_3DB_AVG_MOD_SW, 
		.pfir_ix_gain_db = { ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB  }, 
		.pfir_iy_gain_db = { ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB  }, 
		.pfir_qx_gain_db = { ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB  }, 
		.pfir_qy_gain_db = { ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB  }, 
		.pfir_ix_scalar_gain_db = { 0, 0, 0, 0  }, 
		.pfir_iy_scalar_gain_db = { 0, 0, 0, 0  }, 
		.pfir_qx_scalar_gain_db = { 0, 0, 0, 0  }, 
		.pfir_qy_scalar_gain_db = { 0, 0, 0, 0  }, 
		.hc_prog_delay = { 0, 0, 0, 0  } }  }, 
		.rx_cfir = { { 
		.coeffs_i = { 
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 },
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 }
			 }, 
		.coeffs_q = { 
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 },
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 }
			 }, 
		.cfir_gain_dB = { 
				{ ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB  },
				{ ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB  }
			 }, 
		.scalar_i = { 
				{ 0, 0, 0, 0  },
				{ 0, 0, 0, 0  }
			 }, 
		.scalar_q = { 
				{ 0, 0, 0, 0  },
				{ 0, 0, 0, 0  }
			 }, 
		.enable = false, 
		.sparse_mode = false, 
		.cfir_mode = ADI_APOLLO_CFIR_SINGLE_BAND }, { 
		.coeffs_i = { 
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 },
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 }
			 }, 
		.coeffs_q = { 
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 },
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 }
			 }, 
		.cfir_gain_dB = { 
				{ ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB  },
				{ ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB  }
			 }, 
		.scalar_i = { 
				{ 0, 0, 0, 0  },
				{ 0, 0, 0, 0  }
			 }, 
		.scalar_q = { 
				{ 0, 0, 0, 0  },
				{ 0, 0, 0, 0  }
			 }, 
		.enable = false, 
		.sparse_mode = false, 
		.cfir_mode = ADI_APOLLO_CFIR_SINGLE_BAND }  }, 
		.rx_fsrc = { { 
		.fsrc_rate_int = 0, 
		.fsrc_rate_frac_a = 0, 
		.fsrc_rate_frac_b = 0, 
		.fsrc_delay = 0, 
		.gain_reduction = 0, 
		.ptr_syncrstval = 0, 
		.ptr_overwrite = false, 
		.data_mult_dither_en = false, 
		.dither_en = false, 
		.split_4t4r = false, 
		.mode_1x = false, 
		.enable = false }, { 
		.fsrc_rate_int = 0, 
		.fsrc_rate_frac_a = 0, 
		.fsrc_rate_frac_b = 0, 
		.fsrc_delay = 0, 
		.gain_reduction = 0, 
		.ptr_syncrstval = 0, 
		.ptr_overwrite = false, 
		.data_mult_dither_en = false, 
		.dither_en = false, 
		.split_4t4r = false, 
		.mode_1x = false, 
		.enable = false }  }, 
		.rx_mux_splitter_xbar = { 
		.mux0_out_adc_sel = { (adi_apollo_rx_mux0_sel_e) 0, (adi_apollo_rx_mux0_sel_e) 0, (adi_apollo_rx_mux0_sel_e) 0, (adi_apollo_rx_mux0_sel_e) 0  }, 
		.mux2_fddc_input_sel = { (adi_apollo_rx_mux2_sel_e) 0, (adi_apollo_rx_mux2_sel_e) 0, (adi_apollo_rx_mux2_sel_e) 4, (adi_apollo_rx_mux2_sel_e) 4  }, 
		.low_samp_en = false }
		, 
		.rx_dyn_recfg = { 
		.prefsrc_lcm = 0, 
		.postfsrc_lcm = 0, 
		.trig_recfg_mode = false, 
		.cnco_rst_en = false, 
		.fnco_rst_en = false, 
		.resync_en = false, 
		.ts_rst_en = false, 
		.tzero_coher_en = false }
		, 
		.rx_dformat = { { 
		.inv = false, 
		.sel = ADI_APOLLO_RX_DFORMAT_SEL_2COMP, 
		.ddc_dither_en = false, 
		.res = ADI_APOLLO_RX_DFORMAT_RES_16B, 
		.tmode = { 
		.sel = ADI_APOLLO_RX_4T4R_TMODE_SEL_CONV_DISABLE, 
		.type_sel = ADI_APOLLO_TMODE_TYPE_SEL_NORM, 
		.pn_force_rst = false, 
		.flush = false, 
		.usr_pat_sel = false, 
		.res = ADI_APOLLO_RX_TMODE_RES_16B }
			, 
		.rm_fifo = { 
		.invalid_en = false, 
		.sample_repeat_en = true }
			 }, { 
		.inv = false, 
		.sel = ADI_APOLLO_RX_DFORMAT_SEL_2COMP, 
		.ddc_dither_en = false, 
		.res = ADI_APOLLO_RX_DFORMAT_RES_16B, 
		.tmode = { 
		.sel = ADI_APOLLO_RX_4T4R_TMODE_SEL_CONV_DISABLE, 
		.type_sel = ADI_APOLLO_TMODE_TYPE_SEL_NORM, 
		.pn_force_rst = false, 
		.flush = false, 
		.usr_pat_sel = false, 
		.res = ADI_APOLLO_RX_TMODE_RES_16B }
			, 
		.rm_fifo = { 
		.invalid_en = false, 
		.sample_repeat_en = true }
			 }  }, 
		.rx_smon = { { 
		.period = 0, 
		.gpio_en = false, 
		.peak_en = false, 
		.jlink_sel = ADI_APOLLO_RX_SMON_JLINK_SEL0, 
		.sframer_en = false, 
		.sframer_mode = ADI_APOLLO_RX_SMON_FRAMER_MODE_10B, 
		.sync_en = false, 
		.sync_next = ADI_APOLLO_RX_SMON_SYNC_CONT, 
		.thresh_high = 0, 
		.thresh_low = 0 }, { 
		.period = 0, 
		.gpio_en = false, 
		.peak_en = false, 
		.jlink_sel = ADI_APOLLO_RX_SMON_JLINK_SEL0, 
		.sframer_en = false, 
		.sframer_mode = ADI_APOLLO_RX_SMON_FRAMER_MODE_10B, 
		.sync_en = false, 
		.sync_next = ADI_APOLLO_RX_SMON_SYNC_CONT, 
		.thresh_high = 0, 
		.thresh_low = 0 }, { 
		.period = 0, 
		.gpio_en = false, 
		.peak_en = false, 
		.jlink_sel = ADI_APOLLO_RX_SMON_JLINK_SEL0, 
		.sframer_en = false, 
		.sframer_mode = ADI_APOLLO_RX_SMON_FRAMER_MODE_10B, 
		.sync_en = false, 
		.sync_next = ADI_APOLLO_RX_SMON_SYNC_CONT, 
		.thresh_high = 0, 
		.thresh_low = 0 }, { 
		.period = 0, 
		.gpio_en = false, 
		.peak_en = false, 
		.jlink_sel = ADI_APOLLO_RX_SMON_JLINK_SEL0, 
		.sframer_en = false, 
		.sframer_mode = ADI_APOLLO_RX_SMON_FRAMER_MODE_10B, 
		.sync_en = false, 
		.sync_next = ADI_APOLLO_RX_SMON_SYNC_CONT, 
		.thresh_high = 0, 
		.thresh_low = 0 }  } }, { 
		.rx_cddc = { { 
		.nco = { { 
		.drc_en = true, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_1, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 515396076, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_DIRECT_REGMAP, 
		.nco_auto_inc_dec = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.debug_cdrc_clkoff_n = true }, { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_0p7, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 0, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_TRIG_AUTO, 
		.nco_auto_inc_dec = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.debug_cdrc_clkoff_n = false }  }, 
		.drc_ratio = ADI_APOLLO_CDDC_DCM_4, 
		.fine_bypass = false, 
		.link_num = 0, 
		.hb1_filt_dly_en = false, 
		.hb2_filt_dly_en = false, 
		.tb1_filt_dly_cycles = ADI_APOLLO_TB1_FILT_DLY_DISABLED, 
		.hb1_gain_6db_en = false, 
		.tb1_gain_6db_en = false, 
		.trig_mst_en = false, 
		.trig_mst_period = 0, 
		.trig_mst_offset = 0, 
		.debug_cddc_clkoff_n = 255 }, { 
		.nco = { { 
		.drc_en = true, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_1, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 515396076, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_DIRECT_REGMAP, 
		.nco_auto_inc_dec = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.debug_cdrc_clkoff_n = true }, { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_0p7, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 0, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_TRIG_AUTO, 
		.nco_auto_inc_dec = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.debug_cdrc_clkoff_n = false }  }, 
		.drc_ratio = ADI_APOLLO_CDDC_DCM_4, 
		.fine_bypass = false, 
		.link_num = 0, 
		.hb1_filt_dly_en = false, 
		.hb2_filt_dly_en = false, 
		.tb1_filt_dly_cycles = ADI_APOLLO_TB1_FILT_DLY_DISABLED, 
		.hb1_gain_6db_en = false, 
		.tb1_gain_6db_en = false, 
		.trig_mst_en = false, 
		.trig_mst_period = 0, 
		.trig_mst_offset = 0, 
		.debug_cddc_clkoff_n = 255 }  }, 
		.rx_fddc = { { 
		.nco = { { 
		.drc_en = true, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_COMPLEX, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_1, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 5629499534213, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_DIRECT_REGMAP, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = ADI_APOLLO_FNCO_TRIG_HOP_FREQ, 
		.debug_fdrc_clkoff_n = true }, { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_0p7, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 0, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_TRIG_AUTO, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = (adi_apollo_fnco_trig_hop_sel_e) 0, 
		.debug_fdrc_clkoff_n = false }  }, 
		.drc_ratio = ADI_APOLLO_FDDC_RATIO_2, 
		.link_num = 0, 
		.debug_fddc_clkoff_n = 255, 
		.hb1_filt_dly_en = false, 
		.hb2_filt_dly_en = false, 
		.hb3_filt_dly_en = false, 
		.hb4_filt_dly_en = false, 
		.hb5_filt_dly_en = false, 
		.hb6_filt_dly_en = false, 
		.hb1_gain_6db_en = true }, { 
		.nco = { { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_COMPLEX, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_1, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 5629499534213, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_DIRECT_REGMAP, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = ADI_APOLLO_FNCO_TRIG_HOP_FREQ, 
		.debug_fdrc_clkoff_n = true }, { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_0p7, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 0, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_TRIG_AUTO, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = (adi_apollo_fnco_trig_hop_sel_e) 0, 
		.debug_fdrc_clkoff_n = false }  }, 
		.drc_ratio = ADI_APOLLO_FDDC_RATIO_2, 
		.link_num = 0, 
		.debug_fddc_clkoff_n = 255, 
		.hb1_filt_dly_en = false, 
		.hb2_filt_dly_en = false, 
		.hb3_filt_dly_en = false, 
		.hb4_filt_dly_en = false, 
		.hb5_filt_dly_en = false, 
		.hb6_filt_dly_en = false, 
		.hb1_gain_6db_en = true }, { 
		.nco = { { 
		.drc_en = true, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_COMPLEX, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_1, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 5629499534213, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_DIRECT_REGMAP, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = ADI_APOLLO_FNCO_TRIG_HOP_FREQ, 
		.debug_fdrc_clkoff_n = true }, { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_0p7, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 0, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_TRIG_AUTO, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = (adi_apollo_fnco_trig_hop_sel_e) 0, 
		.debug_fdrc_clkoff_n = false }  }, 
		.drc_ratio = ADI_APOLLO_FDDC_RATIO_2, 
		.link_num = 0, 
		.debug_fddc_clkoff_n = 255, 
		.hb1_filt_dly_en = false, 
		.hb2_filt_dly_en = false, 
		.hb3_filt_dly_en = false, 
		.hb4_filt_dly_en = false, 
		.hb5_filt_dly_en = false, 
		.hb6_filt_dly_en = false, 
		.hb1_gain_6db_en = true }, { 
		.nco = { { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_COMPLEX, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_1, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 5629499534213, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_DIRECT_REGMAP, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = ADI_APOLLO_FNCO_TRIG_HOP_FREQ, 
		.debug_fdrc_clkoff_n = true }, { 
		.drc_en = false, 
		.nco_mode = ADI_APOLLO_NCO_MOD_INTEGER, 
		.nco_if_mode = ADI_APOLLO_MXR_VAR_IF_MODE, 
		.drc_mxr_sel = ADI_APOLLO_DRC_MIXER_REAL, 
		.cmplx_mxr_mult_scale_en = ADI_APOLLO_CMPLX_MULT_SCALE_0p7, 
		.dc_testmode_value = 0, 
		.nco_phase_inc = 0, 
		.nco_phase_offset = 0, 
		.nco_phase_inc_frac_a = 0, 
		.nco_phase_inc_frac_b = 0, 
		.amp_dither_en = false, 
		.phase_dither_en = false, 
		.hop_mode_en = false, 
		.hop_mode = 0, 
		.nco_phase_inc_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_phase_offset_words = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.nco_profile_sel_mode = ADI_APOLLO_NCO_CHAN_SEL_TRIG_AUTO, 
		.nco_auto_inc_dec_freq = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_auto_inc_dec_phase = ADI_APOLLO_NCO_AUTO_HOP_DIR_DECR, 
		.nco_trig_hop_sel = (adi_apollo_fnco_trig_hop_sel_e) 0, 
		.debug_fdrc_clkoff_n = false }  }, 
		.drc_ratio = ADI_APOLLO_FDDC_RATIO_2, 
		.link_num = 0, 
		.debug_fddc_clkoff_n = 255, 
		.hb1_filt_dly_en = false, 
		.hb2_filt_dly_en = false, 
		.hb3_filt_dly_en = false, 
		.hb4_filt_dly_en = false, 
		.hb5_filt_dly_en = false, 
		.hb6_filt_dly_en = false, 
		.hb1_gain_6db_en = true }  }, 
		.rx_pfilt = { { 
		.enable = false, 
		.coeffs = { 
				{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
				{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
				{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
				{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
			 }, 
		.i_mode = ADI_APOLLO_PFILT_MODE_DISABLED, 
		.q_mode = ADI_APOLLO_PFILT_MODE_DISABLED, 
		.real_data = ADI_APOLLO_PFILT_REAL_DATA, 
		.dq_mode = ADI_APOLLO_PFILT_DUAL_MODE, 
		.add_sub_sel = ADI_APOLLO_PFILT_SUB_FOR_MOD_SW, 
		.mode_switch = ADI_APOLLO_PFILT_DISABLE_3DB_AVG_MOD_SW, 
		.pfir_ix_gain_db = { ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB  }, 
		.pfir_iy_gain_db = { ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB  }, 
		.pfir_qx_gain_db = { ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB  }, 
		.pfir_qy_gain_db = { ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB, ADI_APOLLO_PFILT_GAIN_ZERO_DB  }, 
		.pfir_ix_scalar_gain_db = { 0, 0, 0, 0  }, 
		.pfir_iy_scalar_gain_db = { 0, 0, 0, 0  }, 
		.pfir_qx_scalar_gain_db = { 0, 0, 0, 0  }, 
		.pfir_qy_scalar_gain_db = { 0, 0, 0, 0  }, 
		.hc_prog_delay = { 0, 0, 0, 0  } }  }, 
		.rx_cfir = { { 
		.coeffs_i = { 
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 },
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 }
			 }, 
		.coeffs_q = { 
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 },
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 }
			 }, 
		.cfir_gain_dB = { 
				{ ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB  },
				{ ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB  }
			 }, 
		.scalar_i = { 
				{ 0, 0, 0, 0  },
				{ 0, 0, 0, 0  }
			 }, 
		.scalar_q = { 
				{ 0, 0, 0, 0  },
				{ 0, 0, 0, 0  }
			 }, 
		.enable = false, 
		.sparse_mode = false, 
		.cfir_mode = ADI_APOLLO_CFIR_SINGLE_BAND }, { 
		.coeffs_i = { 
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 },
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 }
			 }, 
		.coeffs_q = { 
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 },
				{ 
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  },
					{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }
				 }
			 }, 
		.cfir_gain_dB = { 
				{ ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB  },
				{ ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB, ADI_APOLLO_CFIR_GAIN_MINUS18_DB  }
			 }, 
		.scalar_i = { 
				{ 0, 0, 0, 0  },
				{ 0, 0, 0, 0  }
			 }, 
		.scalar_q = { 
				{ 0, 0, 0, 0  },
				{ 0, 0, 0, 0  }
			 }, 
		.enable = false, 
		.sparse_mode = false, 
		.cfir_mode = ADI_APOLLO_CFIR_SINGLE_BAND }  }, 
		.rx_fsrc = { { 
		.fsrc_rate_int = 0, 
		.fsrc_rate_frac_a = 0, 
		.fsrc_rate_frac_b = 0, 
		.fsrc_delay = 0, 
		.gain_reduction = 0, 
		.ptr_syncrstval = 0, 
		.ptr_overwrite = false, 
		.data_mult_dither_en = false, 
		.dither_en = false, 
		.split_4t4r = false, 
		.mode_1x = false, 
		.enable = false }, { 
		.fsrc_rate_int = 0, 
		.fsrc_rate_frac_a = 0, 
		.fsrc_rate_frac_b = 0, 
		.fsrc_delay = 0, 
		.gain_reduction = 0, 
		.ptr_syncrstval = 0, 
		.ptr_overwrite = false, 
		.data_mult_dither_en = false, 
		.dither_en = false, 
		.split_4t4r = false, 
		.mode_1x = false, 
		.enable = false }  }, 
		.rx_mux_splitter_xbar = { 
		.mux0_out_adc_sel = { (adi_apollo_rx_mux0_sel_e) 0, (adi_apollo_rx_mux0_sel_e) 0, (adi_apollo_rx_mux0_sel_e) 0, (adi_apollo_rx_mux0_sel_e) 0  }, 
		.mux2_fddc_input_sel = { (adi_apollo_rx_mux2_sel_e) 0, (adi_apollo_rx_mux2_sel_e) 0, (adi_apollo_rx_mux2_sel_e) 4, (adi_apollo_rx_mux2_sel_e) 4  }, 
		.low_samp_en = false }
		, 
		.rx_dyn_recfg = { 
		.prefsrc_lcm = 0, 
		.postfsrc_lcm = 0, 
		.trig_recfg_mode = false, 
		.cnco_rst_en = false, 
		.fnco_rst_en = false, 
		.resync_en = false, 
		.ts_rst_en = false, 
		.tzero_coher_en = false }
		, 
		.rx_dformat = { { 
		.inv = false, 
		.sel = ADI_APOLLO_RX_DFORMAT_SEL_2COMP, 
		.ddc_dither_en = false, 
		.res = ADI_APOLLO_RX_DFORMAT_RES_16B, 
		.tmode = { 
		.sel = ADI_APOLLO_RX_4T4R_TMODE_SEL_CONV_DISABLE, 
		.type_sel = ADI_APOLLO_TMODE_TYPE_SEL_NORM, 
		.pn_force_rst = false, 
		.flush = false, 
		.usr_pat_sel = false, 
		.res = ADI_APOLLO_RX_TMODE_RES_16B }
			, 
		.rm_fifo = { 
		.invalid_en = false, 
		.sample_repeat_en = true }
			 }, { 
		.inv = false, 
		.sel = ADI_APOLLO_RX_DFORMAT_SEL_2COMP, 
		.ddc_dither_en = false, 
		.res = ADI_APOLLO_RX_DFORMAT_RES_16B, 
		.tmode = { 
		.sel = ADI_APOLLO_RX_4T4R_TMODE_SEL_CONV_DISABLE, 
		.type_sel = ADI_APOLLO_TMODE_TYPE_SEL_NORM, 
		.pn_force_rst = false, 
		.flush = false, 
		.usr_pat_sel = false, 
		.res = ADI_APOLLO_RX_TMODE_RES_16B }
			, 
		.rm_fifo = { 
		.invalid_en = false, 
		.sample_repeat_en = true }
			 }  }, 
		.rx_smon = { { 
		.period = 0, 
		.gpio_en = false, 
		.peak_en = false, 
		.jlink_sel = ADI_APOLLO_RX_SMON_JLINK_SEL0, 
		.sframer_en = false, 
		.sframer_mode = ADI_APOLLO_RX_SMON_FRAMER_MODE_10B, 
		.sync_en = false, 
		.sync_next = ADI_APOLLO_RX_SMON_SYNC_CONT, 
		.thresh_high = 0, 
		.thresh_low = 0 }, { 
		.period = 0, 
		.gpio_en = false, 
		.peak_en = false, 
		.jlink_sel = ADI_APOLLO_RX_SMON_JLINK_SEL0, 
		.sframer_en = false, 
		.sframer_mode = ADI_APOLLO_RX_SMON_FRAMER_MODE_10B, 
		.sync_en = false, 
		.sync_next = ADI_APOLLO_RX_SMON_SYNC_CONT, 
		.thresh_high = 0, 
		.thresh_low = 0 }, { 
		.period = 0, 
		.gpio_en = false, 
		.peak_en = false, 
		.jlink_sel = ADI_APOLLO_RX_SMON_JLINK_SEL0, 
		.sframer_en = false, 
		.sframer_mode = ADI_APOLLO_RX_SMON_FRAMER_MODE_10B, 
		.sync_en = false, 
		.sync_next = ADI_APOLLO_RX_SMON_SYNC_CONT, 
		.thresh_high = 0, 
		.thresh_low = 0 }, { 
		.period = 0, 
		.gpio_en = false, 
		.peak_en = false, 
		.jlink_sel = ADI_APOLLO_RX_SMON_JLINK_SEL0, 
		.sframer_en = false, 
		.sframer_mode = ADI_APOLLO_RX_SMON_FRAMER_MODE_10B, 
		.sync_en = false, 
		.sync_next = ADI_APOLLO_RX_SMON_SYNC_CONT, 
		.thresh_high = 0, 
		.thresh_low = 0 }  } }  }, 
		.jtx = { { 
		.common_link_cfg = { 
		.ver = ADI_APOLLO_JESD_204C, 
		.subclass = ADI_APOLLO_SUBCLASS_0, 
		.dual_link = false, 
		.lane_enables = 255, 
		.lane_rate_kHz = 20625000 }
		, 
		.tx_link_cfg = { { 
		.link_in_use = true, 
		.e_minus1 = 0, 
		.bank_id = 0, 
		.dev_id = 0, 
		.base_lane_id = 0, 
		.l_minus1 = ADI_APOLLO_LANES_PER_LINK_8, 
		.f_minus1 = ADI_APOLLO_OCT_PER_FRM_1, 
		.m_minus1 = ADI_APOLLO_CONV_PER_LINK_4, 
		.s_minus1 = ADI_APOLLO_SAMP_CONV_FRM_1, 
		.high_dens = true, 
		.k_minus1 = 255, 
		.n_minus1 = ADI_APOLLO_CONV_RESOL_16, 
		.np_minus1 = ADI_APOLLO_BITS_PER_SAMP_16, 
		.ns_minus1 = ADI_APOLLO_SAMP_PER_CONV_8, 
		.cs = ADI_APOLLO_CONT_BITS_PER_SAMP_0, 
		.scr = true, 
		.quick_cfg_en = true, 
		.quick_mode_id = 47, 
		.syncb_in_sel = 0, 
		.syncb_lvds_mode = ADI_APOLLO_JESD_FRM_SYNCB_CMOS, 
		.fec_enable = false, 
		.async_mode = false, 
		.metword_rev = false, 
		.link_dp_ratio = 8, 
		.link_total_ratio = 8, 
		.phase_adjust = 0, 
		.sample_xbar_sel = { ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_Q, ADI_APOLLO_JESD_FRM_SPLXBAR_RX1_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX1_BAND_0_DATA_Q, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I  }, 
		.lane_xbar = { ADI_APOLLO_XBAR_LOGIC_LANE_0, ADI_APOLLO_XBAR_LOGIC_LANE_1, ADI_APOLLO_XBAR_LOGIC_LANE_2, ADI_APOLLO_XBAR_LOGIC_LANE_3, ADI_APOLLO_XBAR_LOGIC_LANE_4, ADI_APOLLO_XBAR_LOGIC_LANE_5, ADI_APOLLO_XBAR_LOGIC_LANE_6, ADI_APOLLO_XBAR_LOGIC_LANE_7, (adi_apollo_jtx_lane_xbar_sel_e) 15, (adi_apollo_jtx_lane_xbar_sel_e) 15, (adi_apollo_jtx_lane_xbar_sel_e) 15, (adi_apollo_jtx_lane_xbar_sel_e) 15  } }, { 
		.link_in_use = false, 
		.e_minus1 = 0, 
		.bank_id = 0, 
		.dev_id = 0, 
		.base_lane_id = 8, 
		.l_minus1 = ADI_APOLLO_LANES_PER_LINK_1, 
		.f_minus1 = ADI_APOLLO_OCT_PER_FRM_1, 
		.m_minus1 = ADI_APOLLO_CONV_PER_LINK_1, 
		.s_minus1 = ADI_APOLLO_SAMP_CONV_FRM_1, 
		.high_dens = false, 
		.k_minus1 = 0, 
		.n_minus1 = (adi_apollo_jesd_conv_resol_e) 0, 
		.np_minus1 = (adi_apollo_jesd_bits_per_samp_e) 0, 
		.ns_minus1 = ADI_APOLLO_SAMP_PER_CONV_1, 
		.cs = ADI_APOLLO_CONT_BITS_PER_SAMP_0, 
		.scr = false, 
		.quick_cfg_en = false, 
		.quick_mode_id = 0, 
		.syncb_in_sel = 0, 
		.syncb_lvds_mode = ADI_APOLLO_JESD_FRM_SYNCB_CMOS, 
		.fec_enable = false, 
		.async_mode = false, 
		.metword_rev = false, 
		.link_dp_ratio = 0, 
		.link_total_ratio = 0, 
		.phase_adjust = 0, 
		.sample_xbar_sel = { ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I  }, 
		.lane_xbar = { ADI_APOLLO_XBAR_LOGIC_LANE_0, ADI_APOLLO_XBAR_LOGIC_LANE_0, ADI_APOLLO_XBAR_LOGIC_LANE_0, ADI_APOLLO_XBAR_LOGIC_LANE_0, ADI_APOLLO_XBAR_LOGIC_LANE_0, ADI_APOLLO_XBAR_LOGIC_LANE_0, ADI_APOLLO_XBAR_LOGIC_LANE_0, ADI_APOLLO_XBAR_LOGIC_LANE_0, ADI_APOLLO_XBAR_LOGIC_LANE_0, ADI_APOLLO_XBAR_LOGIC_LANE_0, ADI_APOLLO_XBAR_LOGIC_LANE_0, ADI_APOLLO_XBAR_LOGIC_LANE_0  } }  }, 
		.serializer_lane = { { 
		.ser_amplitude = ADI_APOLLO_JESD_DRIVE_SWING_VTT_100, 
		.ser_pre_emphasis = ADI_APOLLO_JESD_PRE_TAP_LEVEL_0_DB, 
		.ser_post_emphasis = ADI_APOLLO_JESD_POST_TAP_LEVEL_0_DB, 
		.ser_invert_lane_polarity = false, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1 }, { 
		.ser_amplitude = ADI_APOLLO_JESD_DRIVE_SWING_VTT_100, 
		.ser_pre_emphasis = ADI_APOLLO_JESD_PRE_TAP_LEVEL_0_DB, 
		.ser_post_emphasis = ADI_APOLLO_JESD_POST_TAP_LEVEL_0_DB, 
		.ser_invert_lane_polarity = false, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1 }, { 
		.ser_amplitude = ADI_APOLLO_JESD_DRIVE_SWING_VTT_100, 
		.ser_pre_emphasis = ADI_APOLLO_JESD_PRE_TAP_LEVEL_0_DB, 
		.ser_post_emphasis = ADI_APOLLO_JESD_POST_TAP_LEVEL_0_DB, 
		.ser_invert_lane_polarity = false, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1 }, { 
		.ser_amplitude = ADI_APOLLO_JESD_DRIVE_SWING_VTT_100, 
		.ser_pre_emphasis = ADI_APOLLO_JESD_PRE_TAP_LEVEL_0_DB, 
		.ser_post_emphasis = ADI_APOLLO_JESD_POST_TAP_LEVEL_0_DB, 
		.ser_invert_lane_polarity = false, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1 }, { 
		.ser_amplitude = ADI_APOLLO_JESD_DRIVE_SWING_VTT_100, 
		.ser_pre_emphasis = ADI_APOLLO_JESD_PRE_TAP_LEVEL_0_DB, 
		.ser_post_emphasis = ADI_APOLLO_JESD_POST_TAP_LEVEL_0_DB, 
		.ser_invert_lane_polarity = false, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1 }, { 
		.ser_amplitude = ADI_APOLLO_JESD_DRIVE_SWING_VTT_100, 
		.ser_pre_emphasis = ADI_APOLLO_JESD_PRE_TAP_LEVEL_0_DB, 
		.ser_post_emphasis = ADI_APOLLO_JESD_POST_TAP_LEVEL_0_DB, 
		.ser_invert_lane_polarity = false, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1 }, { 
		.ser_amplitude = ADI_APOLLO_JESD_DRIVE_SWING_VTT_100, 
		.ser_pre_emphasis = ADI_APOLLO_JESD_PRE_TAP_LEVEL_0_DB, 
		.ser_post_emphasis = ADI_APOLLO_JESD_POST_TAP_LEVEL_0_DB, 
		.ser_invert_lane_polarity = false, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1 }, { 
		.ser_amplitude = ADI_APOLLO_JESD_DRIVE_SWING_VTT_100, 
		.ser_pre_emphasis = ADI_APOLLO_JESD_PRE_TAP_LEVEL_0_DB, 
		.ser_post_emphasis = ADI_APOLLO_JESD_POST_TAP_LEVEL_0_DB, 
		.ser_invert_lane_polarity = false, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1 }, { 
		.ser_amplitude = ADI_APOLLO_JESD_DRIVE_SWING_VTT_100, 
		.ser_pre_emphasis = ADI_APOLLO_JESD_PRE_TAP_LEVEL_0_DB, 
		.ser_post_emphasis = ADI_APOLLO_JESD_POST_TAP_LEVEL_0_DB, 
		.ser_invert_lane_polarity = false, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1 }, { 
		.ser_amplitude = ADI_APOLLO_JESD_DRIVE_SWING_VTT_100, 
		.ser_pre_emphasis = ADI_APOLLO_JESD_PRE_TAP_LEVEL_0_DB, 
		.ser_post_emphasis = ADI_APOLLO_JESD_POST_TAP_LEVEL_0_DB, 
		.ser_invert_lane_polarity = false, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1 }, { 
		.ser_amplitude = ADI_APOLLO_JESD_DRIVE_SWING_VTT_100, 
		.ser_pre_emphasis = ADI_APOLLO_JESD_PRE_TAP_LEVEL_0_DB, 
		.ser_post_emphasis = ADI_APOLLO_JESD_POST_TAP_LEVEL_0_DB, 
		.ser_invert_lane_polarity = false, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1 }, { 
		.ser_amplitude = ADI_APOLLO_JESD_DRIVE_SWING_VTT_100, 
		.ser_pre_emphasis = ADI_APOLLO_JESD_PRE_TAP_LEVEL_0_DB, 
		.ser_post_emphasis = ADI_APOLLO_JESD_POST_TAP_LEVEL_0_DB, 
		.ser_invert_lane_polarity = false, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1 }  } }, { 
		.common_link_cfg = { 
		.ver = ADI_APOLLO_JESD_204C, 
		.subclass = ADI_APOLLO_SUBCLASS_0, 
		.dual_link = false, 
		.lane_enables = 255, 
		.lane_rate_kHz = 20625000 }
		, 
		.tx_link_cfg = { { 
		.link_in_use = true, 
		.e_minus1 = 0, 
		.bank_id = 0, 
		.dev_id = 0, 
		.base_lane_id = 0, 
		.l_minus1 = ADI_APOLLO_LANES_PER_LINK_8, 
		.f_minus1 = ADI_APOLLO_OCT_PER_FRM_1, 
		.m_minus1 = ADI_APOLLO_CONV_PER_LINK_4, 
		.s_minus1 = ADI_APOLLO_SAMP_CONV_FRM_1, 
		.high_dens = true, 
		.k_minus1 = 255, 
		.n_minus1 = ADI_APOLLO_CONV_RESOL_16, 
		.np_minus1 = ADI_APOLLO_BITS_PER_SAMP_16, 
		.ns_minus1 = ADI_APOLLO_SAMP_PER_CONV_8, 
		.cs = ADI_APOLLO_CONT_BITS_PER_SAMP_0, 
		.scr = true, 
		.quick_cfg_en = true, 
		.quick_mode_id = 47, 
		.syncb_in_sel = 0, 
		.syncb_lvds_mode = ADI_APOLLO_JESD_FRM_SYNCB_CMOS, 
		.fec_enable = false, 
		.async_mode = false, 
		.metword_rev = false, 
		.link_dp_ratio = 8, 
		.link_total_ratio = 8, 
		.phase_adjust = 0, 
		.sample_xbar_sel = { ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_Q, ADI_APOLLO_JESD_FRM_SPLXBAR_RX1_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX1_BAND_0_DATA_Q, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I  }, 
		.lane_xbar = { ADI_APOLLO_XBAR_LOGIC_LANE_0, ADI_APOLLO_XBAR_LOGIC_LANE_1, ADI_APOLLO_XBAR_LOGIC_LANE_2, ADI_APOLLO_XBAR_LOGIC_LANE_3, ADI_APOLLO_XBAR_LOGIC_LANE_4, ADI_APOLLO_XBAR_LOGIC_LANE_5, ADI_APOLLO_XBAR_LOGIC_LANE_6, ADI_APOLLO_XBAR_LOGIC_LANE_7, (adi_apollo_jtx_lane_xbar_sel_e) 15, (adi_apollo_jtx_lane_xbar_sel_e) 15, (adi_apollo_jtx_lane_xbar_sel_e) 15, (adi_apollo_jtx_lane_xbar_sel_e) 15  } }, { 
		.link_in_use = false, 
		.e_minus1 = 0, 
		.bank_id = 0, 
		.dev_id = 0, 
		.base_lane_id = 8, 
		.l_minus1 = ADI_APOLLO_LANES_PER_LINK_1, 
		.f_minus1 = ADI_APOLLO_OCT_PER_FRM_1, 
		.m_minus1 = ADI_APOLLO_CONV_PER_LINK_1, 
		.s_minus1 = ADI_APOLLO_SAMP_CONV_FRM_1, 
		.high_dens = false, 
		.k_minus1 = 0, 
		.n_minus1 = (adi_apollo_jesd_conv_resol_e) 0, 
		.np_minus1 = (adi_apollo_jesd_bits_per_samp_e) 0, 
		.ns_minus1 = ADI_APOLLO_SAMP_PER_CONV_1, 
		.cs = ADI_APOLLO_CONT_BITS_PER_SAMP_0, 
		.scr = false, 
		.quick_cfg_en = false, 
		.quick_mode_id = 0, 
		.syncb_in_sel = 0, 
		.syncb_lvds_mode = ADI_APOLLO_JESD_FRM_SYNCB_CMOS, 
		.fec_enable = false, 
		.async_mode = false, 
		.metword_rev = false, 
		.link_dp_ratio = 0, 
		.link_total_ratio = 0, 
		.phase_adjust = 0, 
		.sample_xbar_sel = { ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I, ADI_APOLLO_JESD_FRM_SPLXBAR_RX0_BAND_0_DATA_I  }, 
		.lane_xbar = { ADI_APOLLO_XBAR_LOGIC_LANE_0, ADI_APOLLO_XBAR_LOGIC_LANE_0, ADI_APOLLO_XBAR_LOGIC_LANE_0, ADI_APOLLO_XBAR_LOGIC_LANE_0, ADI_APOLLO_XBAR_LOGIC_LANE_0, ADI_APOLLO_XBAR_LOGIC_LANE_0, ADI_APOLLO_XBAR_LOGIC_LANE_0, ADI_APOLLO_XBAR_LOGIC_LANE_0, ADI_APOLLO_XBAR_LOGIC_LANE_0, ADI_APOLLO_XBAR_LOGIC_LANE_0, ADI_APOLLO_XBAR_LOGIC_LANE_0, ADI_APOLLO_XBAR_LOGIC_LANE_0  } }  }, 
		.serializer_lane = { { 
		.ser_amplitude = ADI_APOLLO_JESD_DRIVE_SWING_VTT_100, 
		.ser_pre_emphasis = ADI_APOLLO_JESD_PRE_TAP_LEVEL_0_DB, 
		.ser_post_emphasis = ADI_APOLLO_JESD_POST_TAP_LEVEL_0_DB, 
		.ser_invert_lane_polarity = false, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1 }, { 
		.ser_amplitude = ADI_APOLLO_JESD_DRIVE_SWING_VTT_100, 
		.ser_pre_emphasis = ADI_APOLLO_JESD_PRE_TAP_LEVEL_0_DB, 
		.ser_post_emphasis = ADI_APOLLO_JESD_POST_TAP_LEVEL_0_DB, 
		.ser_invert_lane_polarity = false, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1 }, { 
		.ser_amplitude = ADI_APOLLO_JESD_DRIVE_SWING_VTT_100, 
		.ser_pre_emphasis = ADI_APOLLO_JESD_PRE_TAP_LEVEL_0_DB, 
		.ser_post_emphasis = ADI_APOLLO_JESD_POST_TAP_LEVEL_0_DB, 
		.ser_invert_lane_polarity = false, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1 }, { 
		.ser_amplitude = ADI_APOLLO_JESD_DRIVE_SWING_VTT_100, 
		.ser_pre_emphasis = ADI_APOLLO_JESD_PRE_TAP_LEVEL_0_DB, 
		.ser_post_emphasis = ADI_APOLLO_JESD_POST_TAP_LEVEL_0_DB, 
		.ser_invert_lane_polarity = false, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1 }, { 
		.ser_amplitude = ADI_APOLLO_JESD_DRIVE_SWING_VTT_100, 
		.ser_pre_emphasis = ADI_APOLLO_JESD_PRE_TAP_LEVEL_0_DB, 
		.ser_post_emphasis = ADI_APOLLO_JESD_POST_TAP_LEVEL_0_DB, 
		.ser_invert_lane_polarity = false, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1 }, { 
		.ser_amplitude = ADI_APOLLO_JESD_DRIVE_SWING_VTT_100, 
		.ser_pre_emphasis = ADI_APOLLO_JESD_PRE_TAP_LEVEL_0_DB, 
		.ser_post_emphasis = ADI_APOLLO_JESD_POST_TAP_LEVEL_0_DB, 
		.ser_invert_lane_polarity = false, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1 }, { 
		.ser_amplitude = ADI_APOLLO_JESD_DRIVE_SWING_VTT_100, 
		.ser_pre_emphasis = ADI_APOLLO_JESD_PRE_TAP_LEVEL_0_DB, 
		.ser_post_emphasis = ADI_APOLLO_JESD_POST_TAP_LEVEL_0_DB, 
		.ser_invert_lane_polarity = false, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1 }, { 
		.ser_amplitude = ADI_APOLLO_JESD_DRIVE_SWING_VTT_100, 
		.ser_pre_emphasis = ADI_APOLLO_JESD_PRE_TAP_LEVEL_0_DB, 
		.ser_post_emphasis = ADI_APOLLO_JESD_POST_TAP_LEVEL_0_DB, 
		.ser_invert_lane_polarity = false, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1 }, { 
		.ser_amplitude = ADI_APOLLO_JESD_DRIVE_SWING_VTT_100, 
		.ser_pre_emphasis = ADI_APOLLO_JESD_PRE_TAP_LEVEL_0_DB, 
		.ser_post_emphasis = ADI_APOLLO_JESD_POST_TAP_LEVEL_0_DB, 
		.ser_invert_lane_polarity = false, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1 }, { 
		.ser_amplitude = ADI_APOLLO_JESD_DRIVE_SWING_VTT_100, 
		.ser_pre_emphasis = ADI_APOLLO_JESD_PRE_TAP_LEVEL_0_DB, 
		.ser_post_emphasis = ADI_APOLLO_JESD_POST_TAP_LEVEL_0_DB, 
		.ser_invert_lane_polarity = false, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1 }, { 
		.ser_amplitude = ADI_APOLLO_JESD_DRIVE_SWING_VTT_100, 
		.ser_pre_emphasis = ADI_APOLLO_JESD_PRE_TAP_LEVEL_0_DB, 
		.ser_post_emphasis = ADI_APOLLO_JESD_POST_TAP_LEVEL_0_DB, 
		.ser_invert_lane_polarity = false, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1 }, { 
		.ser_amplitude = ADI_APOLLO_JESD_DRIVE_SWING_VTT_100, 
		.ser_pre_emphasis = ADI_APOLLO_JESD_PRE_TAP_LEVEL_0_DB, 
		.ser_post_emphasis = ADI_APOLLO_JESD_POST_TAP_LEVEL_0_DB, 
		.ser_invert_lane_polarity = false, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1 }  } }  }, 
		.jrx = { { 
		.common_link_cfg = { 
		.ver = ADI_APOLLO_JESD_204C, 
		.subclass = ADI_APOLLO_SUBCLASS_0, 
		.dual_link = false, 
		.lane_enables = 255, 
		.lane_rate_kHz = 20625000 }
		, 
		.rx_link_cfg = { { 
		.link_in_use = true, 
		.e_minus1 = 0, 
		.bank_id = 0, 
		.dev_id = 0, 
		.base_lane_id = 0, 
		.l_minus1 = ADI_APOLLO_LANES_PER_LINK_8, 
		.f_minus1 = ADI_APOLLO_OCT_PER_FRM_1, 
		.m_minus1 = ADI_APOLLO_CONV_PER_LINK_4, 
		.s_minus1 = ADI_APOLLO_SAMP_CONV_FRM_1, 
		.high_dens = true, 
		.k_minus1 = 255, 
		.n_minus1 = ADI_APOLLO_CONV_RESOL_16, 
		.np_minus1 = ADI_APOLLO_BITS_PER_SAMP_16, 
		.ns_minus1 = ADI_APOLLO_SAMP_PER_CONV_8, 
		.cs = ADI_APOLLO_CONT_BITS_PER_SAMP_0, 
		.scr = true, 
		.quick_cfg_en = true, 
		.quick_mode_id = 47, 
		.syncb_out_sel = ADI_APOLLO_JESD_DFRM_PWR_ON_SYNC_PAD1, 
		.syncb_lvds_mode = ADI_APOLLO_JESD_FRM_SYNCB_CMOS, 
		.link_dp_ratio = 8, 
		.link_total_ratio = 8, 
		.invalid_data_en = false, 
		.invalid_sample_num = 0, 
		.sample_repeat_en = true, 
		.phase_adjust = 0, 
		.sample_xbar_sel = { ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX1_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX1_BAND_0_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX2_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX2_BAND_0_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX3_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX3_BAND_0_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX4_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX4_BAND_0_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX5_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX5_BAND_0_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX6_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX6_BAND_0_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX7_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX7_BAND_0_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_1_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_1_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX1_BAND_1_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX1_BAND_1_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX2_BAND_1_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX2_BAND_1_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX3_BAND_1_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX3_BAND_1_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX4_BAND_1_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX4_BAND_1_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX5_BAND_1_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX5_BAND_1_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX6_BAND_1_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX6_BAND_1_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX7_BAND_1_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX7_BAND_1_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I  }, 
		.lane_xbar = { ADI_APOLLO_XBAR_PHY_LANE_0, ADI_APOLLO_XBAR_PHY_LANE_1, ADI_APOLLO_XBAR_PHY_LANE_2, ADI_APOLLO_XBAR_PHY_LANE_3, ADI_APOLLO_XBAR_PHY_LANE_4, ADI_APOLLO_XBAR_PHY_LANE_5, ADI_APOLLO_XBAR_PHY_LANE_6, ADI_APOLLO_XBAR_PHY_LANE_7, (adi_apollo_jrx_lane_xbar_sel_e) 15, (adi_apollo_jrx_lane_xbar_sel_e) 15, (adi_apollo_jrx_lane_xbar_sel_e) 15, (adi_apollo_jrx_lane_xbar_sel_e) 15  } }, { 
		.link_in_use = false, 
		.e_minus1 = 0, 
		.bank_id = 0, 
		.dev_id = 0, 
		.base_lane_id = 8, 
		.l_minus1 = ADI_APOLLO_LANES_PER_LINK_1, 
		.f_minus1 = ADI_APOLLO_OCT_PER_FRM_1, 
		.m_minus1 = ADI_APOLLO_CONV_PER_LINK_1, 
		.s_minus1 = ADI_APOLLO_SAMP_CONV_FRM_1, 
		.high_dens = false, 
		.k_minus1 = 0, 
		.n_minus1 = (adi_apollo_jesd_conv_resol_e) 0, 
		.np_minus1 = (adi_apollo_jesd_bits_per_samp_e) 0, 
		.ns_minus1 = ADI_APOLLO_SAMP_PER_CONV_1, 
		.cs = ADI_APOLLO_CONT_BITS_PER_SAMP_0, 
		.scr = false, 
		.quick_cfg_en = false, 
		.quick_mode_id = 0, 
		.syncb_out_sel = ADI_APOLLO_JESD_DFRM_PWR_ON_SYNC_PAD1, 
		.syncb_lvds_mode = ADI_APOLLO_JESD_FRM_SYNCB_CMOS, 
		.link_dp_ratio = 0, 
		.link_total_ratio = 0, 
		.invalid_data_en = false, 
		.invalid_sample_num = 0, 
		.sample_repeat_en = false, 
		.phase_adjust = 0, 
		.sample_xbar_sel = { ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I  }, 
		.lane_xbar = { ADI_APOLLO_XBAR_PHY_LANE_0, ADI_APOLLO_XBAR_PHY_LANE_0, ADI_APOLLO_XBAR_PHY_LANE_0, ADI_APOLLO_XBAR_PHY_LANE_0, ADI_APOLLO_XBAR_PHY_LANE_0, ADI_APOLLO_XBAR_PHY_LANE_0, ADI_APOLLO_XBAR_PHY_LANE_0, ADI_APOLLO_XBAR_PHY_LANE_0, ADI_APOLLO_XBAR_PHY_LANE_0, ADI_APOLLO_XBAR_PHY_LANE_0, ADI_APOLLO_XBAR_PHY_LANE_0, ADI_APOLLO_XBAR_PHY_LANE_0  } }  }, 
		.deserializer_lane = { { 
		.high_boost_options = 8, 
		.des_inv_lane_pol = false, 
		.rx_des_qhf_rate = ADI_APOLLO_DESER_RATE_MODE_QUARTER_RATE, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1, 
		.config_options = { 336, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.override_settings = { 
		.names = { ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID  }, 
		.values = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  } }
			 }, { 
		.high_boost_options = 8, 
		.des_inv_lane_pol = false, 
		.rx_des_qhf_rate = ADI_APOLLO_DESER_RATE_MODE_QUARTER_RATE, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1, 
		.config_options = { 336, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.override_settings = { 
		.names = { ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID  }, 
		.values = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  } }
			 }, { 
		.high_boost_options = 8, 
		.des_inv_lane_pol = false, 
		.rx_des_qhf_rate = ADI_APOLLO_DESER_RATE_MODE_QUARTER_RATE, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1, 
		.config_options = { 336, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.override_settings = { 
		.names = { ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID  }, 
		.values = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  } }
			 }, { 
		.high_boost_options = 8, 
		.des_inv_lane_pol = false, 
		.rx_des_qhf_rate = ADI_APOLLO_DESER_RATE_MODE_QUARTER_RATE, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1, 
		.config_options = { 336, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.override_settings = { 
		.names = { ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID  }, 
		.values = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  } }
			 }, { 
		.high_boost_options = 8, 
		.des_inv_lane_pol = false, 
		.rx_des_qhf_rate = ADI_APOLLO_DESER_RATE_MODE_QUARTER_RATE, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1, 
		.config_options = { 336, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.override_settings = { 
		.names = { ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID  }, 
		.values = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  } }
			 }, { 
		.high_boost_options = 8, 
		.des_inv_lane_pol = false, 
		.rx_des_qhf_rate = ADI_APOLLO_DESER_RATE_MODE_QUARTER_RATE, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1, 
		.config_options = { 336, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.override_settings = { 
		.names = { ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID  }, 
		.values = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  } }
			 }, { 
		.high_boost_options = 8, 
		.des_inv_lane_pol = false, 
		.rx_des_qhf_rate = ADI_APOLLO_DESER_RATE_MODE_QUARTER_RATE, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1, 
		.config_options = { 336, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.override_settings = { 
		.names = { ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID  }, 
		.values = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  } }
			 }, { 
		.high_boost_options = 8, 
		.des_inv_lane_pol = false, 
		.rx_des_qhf_rate = ADI_APOLLO_DESER_RATE_MODE_QUARTER_RATE, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1, 
		.config_options = { 336, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.override_settings = { 
		.names = { ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID  }, 
		.values = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  } }
			 }, { 
		.high_boost_options = 8, 
		.des_inv_lane_pol = false, 
		.rx_des_qhf_rate = ADI_APOLLO_DESER_RATE_MODE_QUARTER_RATE, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1, 
		.config_options = { 336, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.override_settings = { 
		.names = { ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID  }, 
		.values = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  } }
			 }, { 
		.high_boost_options = 8, 
		.des_inv_lane_pol = false, 
		.rx_des_qhf_rate = ADI_APOLLO_DESER_RATE_MODE_QUARTER_RATE, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1, 
		.config_options = { 336, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.override_settings = { 
		.names = { ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID  }, 
		.values = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  } }
			 }, { 
		.high_boost_options = 8, 
		.des_inv_lane_pol = false, 
		.rx_des_qhf_rate = ADI_APOLLO_DESER_RATE_MODE_QUARTER_RATE, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1, 
		.config_options = { 336, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.override_settings = { 
		.names = { ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID  }, 
		.values = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  } }
			 }, { 
		.high_boost_options = 8, 
		.des_inv_lane_pol = false, 
		.rx_des_qhf_rate = ADI_APOLLO_DESER_RATE_MODE_QUARTER_RATE, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1, 
		.config_options = { 336, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.override_settings = { 
		.names = { ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID  }, 
		.values = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  } }
			 }  } }, { 
		.common_link_cfg = { 
		.ver = ADI_APOLLO_JESD_204C, 
		.subclass = ADI_APOLLO_SUBCLASS_0, 
		.dual_link = false, 
		.lane_enables = 255, 
		.lane_rate_kHz = 20625000 }
		, 
		.rx_link_cfg = { { 
		.link_in_use = true, 
		.e_minus1 = 0, 
		.bank_id = 0, 
		.dev_id = 0, 
		.base_lane_id = 0, 
		.l_minus1 = ADI_APOLLO_LANES_PER_LINK_8, 
		.f_minus1 = ADI_APOLLO_OCT_PER_FRM_1, 
		.m_minus1 = ADI_APOLLO_CONV_PER_LINK_4, 
		.s_minus1 = ADI_APOLLO_SAMP_CONV_FRM_1, 
		.high_dens = true, 
		.k_minus1 = 255, 
		.n_minus1 = ADI_APOLLO_CONV_RESOL_16, 
		.np_minus1 = ADI_APOLLO_BITS_PER_SAMP_16, 
		.ns_minus1 = ADI_APOLLO_SAMP_PER_CONV_8, 
		.cs = ADI_APOLLO_CONT_BITS_PER_SAMP_0, 
		.scr = true, 
		.quick_cfg_en = true, 
		.quick_mode_id = 47, 
		.syncb_out_sel = ADI_APOLLO_JESD_DFRM_PWR_ON_SYNC_PAD1, 
		.syncb_lvds_mode = ADI_APOLLO_JESD_FRM_SYNCB_CMOS, 
		.link_dp_ratio = 8, 
		.link_total_ratio = 8, 
		.invalid_data_en = false, 
		.invalid_sample_num = 0, 
		.sample_repeat_en = true, 
		.phase_adjust = 0, 
		.sample_xbar_sel = { ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX1_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX1_BAND_0_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX2_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX2_BAND_0_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX3_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX3_BAND_0_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX4_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX4_BAND_0_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX5_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX5_BAND_0_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX6_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX6_BAND_0_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX7_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX7_BAND_0_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_1_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_1_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX1_BAND_1_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX1_BAND_1_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX2_BAND_1_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX2_BAND_1_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX3_BAND_1_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX3_BAND_1_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX4_BAND_1_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX4_BAND_1_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX5_BAND_1_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX5_BAND_1_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX6_BAND_1_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX6_BAND_1_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX7_BAND_1_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX7_BAND_1_DATA_Q, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I  }, 
		.lane_xbar = { ADI_APOLLO_XBAR_PHY_LANE_0, ADI_APOLLO_XBAR_PHY_LANE_1, ADI_APOLLO_XBAR_PHY_LANE_2, ADI_APOLLO_XBAR_PHY_LANE_3, ADI_APOLLO_XBAR_PHY_LANE_4, ADI_APOLLO_XBAR_PHY_LANE_5, ADI_APOLLO_XBAR_PHY_LANE_6, ADI_APOLLO_XBAR_PHY_LANE_7, (adi_apollo_jrx_lane_xbar_sel_e) 15, (adi_apollo_jrx_lane_xbar_sel_e) 15, (adi_apollo_jrx_lane_xbar_sel_e) 15, (adi_apollo_jrx_lane_xbar_sel_e) 15  } }, { 
		.link_in_use = false, 
		.e_minus1 = 0, 
		.bank_id = 0, 
		.dev_id = 0, 
		.base_lane_id = 8, 
		.l_minus1 = ADI_APOLLO_LANES_PER_LINK_1, 
		.f_minus1 = ADI_APOLLO_OCT_PER_FRM_1, 
		.m_minus1 = ADI_APOLLO_CONV_PER_LINK_1, 
		.s_minus1 = ADI_APOLLO_SAMP_CONV_FRM_1, 
		.high_dens = false, 
		.k_minus1 = 0, 
		.n_minus1 = (adi_apollo_jesd_conv_resol_e) 0, 
		.np_minus1 = (adi_apollo_jesd_bits_per_samp_e) 0, 
		.ns_minus1 = ADI_APOLLO_SAMP_PER_CONV_1, 
		.cs = ADI_APOLLO_CONT_BITS_PER_SAMP_0, 
		.scr = false, 
		.quick_cfg_en = false, 
		.quick_mode_id = 0, 
		.syncb_out_sel = ADI_APOLLO_JESD_DFRM_PWR_ON_SYNC_PAD1, 
		.syncb_lvds_mode = ADI_APOLLO_JESD_FRM_SYNCB_CMOS, 
		.link_dp_ratio = 0, 
		.link_total_ratio = 0, 
		.invalid_data_en = false, 
		.invalid_sample_num = 0, 
		.sample_repeat_en = false, 
		.phase_adjust = 0, 
		.sample_xbar_sel = { ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I, ADI_APOLLO_JESD_DFRM_SPLXBAR_TX0_BAND_0_DATA_I  }, 
		.lane_xbar = { ADI_APOLLO_XBAR_PHY_LANE_0, ADI_APOLLO_XBAR_PHY_LANE_0, ADI_APOLLO_XBAR_PHY_LANE_0, ADI_APOLLO_XBAR_PHY_LANE_0, ADI_APOLLO_XBAR_PHY_LANE_0, ADI_APOLLO_XBAR_PHY_LANE_0, ADI_APOLLO_XBAR_PHY_LANE_0, ADI_APOLLO_XBAR_PHY_LANE_0, ADI_APOLLO_XBAR_PHY_LANE_0, ADI_APOLLO_XBAR_PHY_LANE_0, ADI_APOLLO_XBAR_PHY_LANE_0, ADI_APOLLO_XBAR_PHY_LANE_0  } }  }, 
		.deserializer_lane = { { 
		.high_boost_options = 8, 
		.des_inv_lane_pol = false, 
		.rx_des_qhf_rate = ADI_APOLLO_DESER_RATE_MODE_QUARTER_RATE, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1, 
		.config_options = { 336, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.override_settings = { 
		.names = { ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID  }, 
		.values = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  } }
			 }, { 
		.high_boost_options = 8, 
		.des_inv_lane_pol = false, 
		.rx_des_qhf_rate = ADI_APOLLO_DESER_RATE_MODE_QUARTER_RATE, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1, 
		.config_options = { 336, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.override_settings = { 
		.names = { ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID  }, 
		.values = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  } }
			 }, { 
		.high_boost_options = 8, 
		.des_inv_lane_pol = false, 
		.rx_des_qhf_rate = ADI_APOLLO_DESER_RATE_MODE_QUARTER_RATE, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1, 
		.config_options = { 336, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.override_settings = { 
		.names = { ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID  }, 
		.values = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  } }
			 }, { 
		.high_boost_options = 8, 
		.des_inv_lane_pol = false, 
		.rx_des_qhf_rate = ADI_APOLLO_DESER_RATE_MODE_QUARTER_RATE, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1, 
		.config_options = { 336, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.override_settings = { 
		.names = { ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID  }, 
		.values = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  } }
			 }, { 
		.high_boost_options = 8, 
		.des_inv_lane_pol = false, 
		.rx_des_qhf_rate = ADI_APOLLO_DESER_RATE_MODE_QUARTER_RATE, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1, 
		.config_options = { 336, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.override_settings = { 
		.names = { ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID  }, 
		.values = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  } }
			 }, { 
		.high_boost_options = 8, 
		.des_inv_lane_pol = false, 
		.rx_des_qhf_rate = ADI_APOLLO_DESER_RATE_MODE_QUARTER_RATE, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1, 
		.config_options = { 336, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.override_settings = { 
		.names = { ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID  }, 
		.values = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  } }
			 }, { 
		.high_boost_options = 8, 
		.des_inv_lane_pol = false, 
		.rx_des_qhf_rate = ADI_APOLLO_DESER_RATE_MODE_QUARTER_RATE, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1, 
		.config_options = { 336, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.override_settings = { 
		.names = { ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID  }, 
		.values = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  } }
			 }, { 
		.high_boost_options = 8, 
		.des_inv_lane_pol = false, 
		.rx_des_qhf_rate = ADI_APOLLO_DESER_RATE_MODE_QUARTER_RATE, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1, 
		.config_options = { 336, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.override_settings = { 
		.names = { ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID  }, 
		.values = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  } }
			 }, { 
		.high_boost_options = 8, 
		.des_inv_lane_pol = false, 
		.rx_des_qhf_rate = ADI_APOLLO_DESER_RATE_MODE_QUARTER_RATE, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1, 
		.config_options = { 336, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.override_settings = { 
		.names = { ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID  }, 
		.values = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  } }
			 }, { 
		.high_boost_options = 8, 
		.des_inv_lane_pol = false, 
		.rx_des_qhf_rate = ADI_APOLLO_DESER_RATE_MODE_QUARTER_RATE, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1, 
		.config_options = { 336, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.override_settings = { 
		.names = { ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID  }, 
		.values = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  } }
			 }, { 
		.high_boost_options = 8, 
		.des_inv_lane_pol = false, 
		.rx_des_qhf_rate = ADI_APOLLO_DESER_RATE_MODE_QUARTER_RATE, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1, 
		.config_options = { 336, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.override_settings = { 
		.names = { ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID  }, 
		.values = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  } }
			 }, { 
		.high_boost_options = 8, 
		.des_inv_lane_pol = false, 
		.rx_des_qhf_rate = ADI_APOLLO_DESER_RATE_MODE_QUARTER_RATE, 
		.lanerate_adapt = ADI_APOLLO_SERDES_LR_ADAPT_RATIO_1, 
		.config_options = { 336, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.override_settings = { 
		.names = { ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID, ADI_APOLLO_DESER_INVALID  }, 
		.values = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  } }
			 }  } }  }, 
		.dac_config = { { 
		.dac_sampling_rate_Hz = 20000000000, 
		.dynamic_dac_en = false, 
		.shuffle_en = { true, true, true, true  }, 
		.scrambler_en = { true, true, true, true  } }, { 
		.dac_sampling_rate_Hz = 20000000000, 
		.dynamic_dac_en = false, 
		.shuffle_en = { true, true, true, true  }, 
		.scrambler_en = { true, true, true, true  } }  }, 
		.adc_config = { { 
		.adc_sampling_rate_Hz = 20000000000, 
		.adc_init_cal_index = 7, 
		.adc_slice_mode = { ADI_APOLLO_ADC_SLICE_PPRAND3P1, ADI_APOLLO_ADC_SLICE_PPRAND3P1, ADI_APOLLO_ADC_SLICE_PPRAND3P1, ADI_APOLLO_ADC_SLICE_PPRAND3P1  }, 
		.adc_track_mode = { ADI_APOLLO_ADC_TRACK_SEQ2, ADI_APOLLO_ADC_TRACK_SEQ2, ADI_APOLLO_ADC_TRACK_SEQ2, ADI_APOLLO_ADC_TRACK_SEQ2  }, 
		.full_scale_adj = { 0, 0, 0, 0  }, 
		.inp_coupling_type = { ADI_APOLLO_ADC_INPUT_COUPLING_AC, ADI_APOLLO_ADC_INPUT_COUPLING_AC, ADI_APOLLO_ADC_INPUT_COUPLING_AC, ADI_APOLLO_ADC_INPUT_COUPLING_AC  }, 
		.inp_signal_type = { ADI_APOLLO_ADC_INPUT_SIGNAL_DIFFERENTIAL, ADI_APOLLO_ADC_INPUT_SIGNAL_DIFFERENTIAL, ADI_APOLLO_ADC_INPUT_SIGNAL_DIFFERENTIAL, ADI_APOLLO_ADC_INPUT_SIGNAL_DIFFERENTIAL  }, 
		.inp_polarity = { ADI_APOLLO_ADC_INPUT_POLARITY_NORMAL, ADI_APOLLO_ADC_INPUT_POLARITY_NORMAL, ADI_APOLLO_ADC_INPUT_POLARITY_NORMAL, ADI_APOLLO_ADC_INPUT_POLARITY_NORMAL  }, 
		.adc_options = { 0, 0, 0, 0, 0, 0, 0, 0  } }, { 
		.adc_sampling_rate_Hz = 20000000000, 
		.adc_init_cal_index = 7, 
		.adc_slice_mode = { ADI_APOLLO_ADC_SLICE_PPRAND3P1, ADI_APOLLO_ADC_SLICE_PPRAND3P1, ADI_APOLLO_ADC_SLICE_PPRAND3P1, ADI_APOLLO_ADC_SLICE_PPRAND3P1  }, 
		.adc_track_mode = { ADI_APOLLO_ADC_TRACK_SEQ2, ADI_APOLLO_ADC_TRACK_SEQ2, ADI_APOLLO_ADC_TRACK_SEQ2, ADI_APOLLO_ADC_TRACK_SEQ2  }, 
		.full_scale_adj = { 0, 0, 0, 0  }, 
		.inp_coupling_type = { ADI_APOLLO_ADC_INPUT_COUPLING_AC, ADI_APOLLO_ADC_INPUT_COUPLING_AC, ADI_APOLLO_ADC_INPUT_COUPLING_AC, ADI_APOLLO_ADC_INPUT_COUPLING_AC  }, 
		.inp_signal_type = { ADI_APOLLO_ADC_INPUT_SIGNAL_DIFFERENTIAL, ADI_APOLLO_ADC_INPUT_SIGNAL_DIFFERENTIAL, ADI_APOLLO_ADC_INPUT_SIGNAL_DIFFERENTIAL, ADI_APOLLO_ADC_INPUT_SIGNAL_DIFFERENTIAL  }, 
		.inp_polarity = { ADI_APOLLO_ADC_INPUT_POLARITY_NORMAL, ADI_APOLLO_ADC_INPUT_POLARITY_NORMAL, ADI_APOLLO_ADC_INPUT_POLARITY_NORMAL, ADI_APOLLO_ADC_INPUT_POLARITY_NORMAL  }, 
		.adc_options = { 0, 0, 0, 0, 0, 0, 0, 0  } }  }, 
		.lb0_en = { 
		{ false, false  },
		{ false, false  }
	 }, 
		.linx_cfg = { { 
		.gpio_index = 0, 
		.gpio_invert = false, 
		.signal_injection_dac = ADI_APOLLO_TX_CH_A0, 
		.reserved = 0 }, { 
		.gpio_index = 0, 
		.gpio_invert = false, 
		.signal_injection_dac = ADI_APOLLO_TX_CH_A0, 
		.reserved = 0 }, { 
		.gpio_index = 0, 
		.gpio_invert = false, 
		.signal_injection_dac = ADI_APOLLO_TX_CH_A0, 
		.reserved = 0 }, { 
		.gpio_index = 0, 
		.gpio_invert = false, 
		.signal_injection_dac = ADI_APOLLO_TX_CH_A0, 
		.reserved = 0 }  }, 
		.serdes_pll = { 
		.loop_bandwidth = 1000000, 
		.phase_margin = 50, 
		.div_range = 0, 
		.div2 = 0, 
		.power = 1, 
		.ref_clk_div = 1, 
		.i_bleed_en = 0, 
		.serdes_pll_odiv = 1, 
		.feedback_int = 66, 
		.feedback_frac = 0 }
	, 
		.adc_enable = 51, 
		.dac_enable = 51, 
		.reserved_cfg = { 244, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0  }, 
		.profile_checksum = 612689891 };

#endif /* __ADI_ID00_STOCK_MODE_H__ */
